Class: Google::Cloud::Dataform::V1beta1::CodeCompilationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::CodeCompilationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Configures various aspects of Dataform code compilation.
Defined Under Namespace
Classes: VarsEntry
Instance Attribute Summary collapse
-
#assertion_schema ⇒ ::String
Optional.
-
#builtin_assertion_name_prefix ⇒ ::String
Optional.
-
#database_suffix ⇒ ::String
Optional.
-
#default_database ⇒ ::String
Optional.
-
#default_location ⇒ ::String
Optional.
-
#default_notebook_runtime_options ⇒ ::Google::Cloud::Dataform::V1beta1::NotebookRuntimeOptions
Optional.
-
#default_schema ⇒ ::String
Optional.
-
#pipeline_config ⇒ ::Google::Cloud::Dataform::V1beta1::PipelineConfig
Optional.
-
#schema_suffix ⇒ ::String
Optional.
-
#table_prefix ⇒ ::String
Optional.
-
#vars ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
Instance Attribute Details
#assertion_schema ⇒ ::String
Returns Optional. The default schema (BigQuery dataset ID) for assertions.
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#builtin_assertion_name_prefix ⇒ ::String
Returns Optional. The prefix to prepend to built-in assertion names.
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#database_suffix ⇒ ::String
Returns Optional. The suffix that should be appended to all database (Google Cloud project ID) names.
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_database ⇒ ::String
Returns Optional. The default database (Google Cloud project ID).
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_location ⇒ ::String
Returns Optional. The default BigQuery location to use. Defaults to "US". See the BigQuery docs for a full list of locations: https://cloud.google.com/bigquery/docs/locations.
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_notebook_runtime_options ⇒ ::Google::Cloud::Dataform::V1beta1::NotebookRuntimeOptions
Returns Optional. The default notebook runtime options.
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_schema ⇒ ::String
Returns Optional. The default schema (BigQuery dataset ID).
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#pipeline_config ⇒ ::Google::Cloud::Dataform::V1beta1::PipelineConfig
Returns Optional. The pipeline options which defines the pipeline type and path within the Git repository.
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#schema_suffix ⇒ ::String
Returns Optional. The suffix that should be appended to all schema (BigQuery dataset ID) names.
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#table_prefix ⇒ ::String
Returns Optional. The prefix that should be prepended to all table names.
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#vars ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. User-defined variables that are made available to project code during compilation.
1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1617 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |