Class: Google::Cloud::Dataform::V1beta1::CompilationResult::CodeCompilationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::CompilationResult::CodeCompilationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Configures various aspects of Dataform code compilation.
Defined Under Namespace
Classes: VarsEntry
Instance Attribute Summary collapse
-
#assertion_schema ⇒ ::String
Optional.
-
#database_suffix ⇒ ::String
Optional.
-
#default_database ⇒ ::String
Optional.
-
#default_location ⇒ ::String
Optional.
-
#default_schema ⇒ ::String
Optional.
-
#schema_suffix ⇒ ::String
Optional.
-
#table_prefix ⇒ ::String
Optional.
-
#vars ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
Instance Attribute Details
#assertion_schema ⇒ ::String
Returns Optional. The default schema (BigQuery dataset ID) for assertions.
708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 708 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#database_suffix ⇒ ::String
Returns Optional. The suffix that should be appended to all database (Google Cloud project ID) names.
708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 708 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_database ⇒ ::String
Returns Optional. The default database (Google Cloud project ID).
708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 708 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_location ⇒ ::String
Returns Optional. The default BigQuery location to use. Defaults to "US". See the BigQuery docs for a full list of locations: https://cloud.google.com/bigquery/docs/locations.
708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 708 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#default_schema ⇒ ::String
Returns Optional. The default schema (BigQuery dataset ID).
708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 708 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#schema_suffix ⇒ ::String
Returns Optional. The suffix that should be appended to all schema (BigQuery dataset ID) names.
708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 708 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#table_prefix ⇒ ::String
Returns Optional. The prefix that should be prepended to all table names.
708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 708 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#vars ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. User-defined variables that are made available to project code during compilation.
708 709 710 711 712 713 714 715 716 717 718 719 720 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 708 class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |