Class: Google::Cloud::Dataform::V1beta1::CompilationResultAction
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::CompilationResultAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a single Dataform action in a compilation result.
Defined Under Namespace
Classes: Assertion, Declaration, Operations, Relation
Instance Attribute Summary collapse
-
#assertion ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Assertion
The assertion executed by this action.
-
#canonical_target ⇒ ::Google::Cloud::Dataform::V1beta1::Target
The action's identifier if the project had been compiled without any overrides configured.
-
#declaration ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Declaration
The declaration declared by this action.
-
#file_path ⇒ ::String
The full path including filename in which this action is located, relative to the workspace root.
-
#operations ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Operations
The database operations executed by this action.
-
#relation ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation
The database relation created/updated by this action.
-
#target ⇒ ::Google::Cloud::Dataform::V1beta1::Target
This action's identifier.
Instance Attribute Details
#assertion ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Assertion
Returns The assertion executed by this action.
882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 882 class CompilationResultAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a database relation. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. # @!attribute [rw] relation_type # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType] # The type of this relation. # @!attribute [rw] select_query # @return [::String] # The SELECT query which returns rows which this relation should contain. # @!attribute [rw] pre_operations # @return [::Array<::String>] # SQL statements to be executed before creating the relation. # @!attribute [rw] post_operations # @return [::Array<::String>] # SQL statements to be executed after creating the relation. # @!attribute [rw] incremental_table_config # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig] # Configures `INCREMENTAL_TABLE` settings for this relation. Only set if # `relation_type` is `INCREMENTAL_TABLE`. # @!attribute [rw] partition_expression # @return [::String] # The SQL expression used to partition the relation. # @!attribute [rw] cluster_expressions # @return [::Array<::String>] # A list of columns or SQL expressions used to cluster the table. # @!attribute [rw] partition_expiration_days # @return [::Integer] # Sets the partition expiration in days. # @!attribute [rw] require_partition_filter # @return [::Boolean] # Specifies whether queries on this table must include a predicate filter # that filters on the partitioning column. # @!attribute [rw] additional_options # @return [::Google::Protobuf::Map{::String => ::String}] # Additional options that will be provided as key/value pairs into the # options clause of a create table/view statement. See # https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language # for more information on which options are supported. class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end end # Represents a list of arbitrary database operations. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for any output relation and its columns. Only set if # `has_output` is true. # @!attribute [rw] queries # @return [::Array<::String>] # A list of arbitrary SQL statements that will be executed without # alteration. # @!attribute [rw] has_output # @return [::Boolean] # Whether these operations produce an output relation. class Operations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents an assertion upon a SQL query which is required return zero # rows. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] parent_action # @return [::Google::Cloud::Dataform::V1beta1::Target] # The parent action of this assertion. Only set if this assertion was # automatically generated. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] select_query # @return [::String] # The SELECT query which must return zero rows in order for this assertion # to succeed. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the assertion's automatically-generated view and its # columns. class Assertion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a relation which is not managed by Dataform but which may be # referenced by Dataform actions. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. Used as documentation only, # i.e. values here will result in no changes to the relation's metadata. class Declaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#canonical_target ⇒ ::Google::Cloud::Dataform::V1beta1::Target
Returns The action's identifier if the project had been compiled without any overrides configured. Unique within the compilation result.
882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 882 class CompilationResultAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a database relation. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. # @!attribute [rw] relation_type # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType] # The type of this relation. # @!attribute [rw] select_query # @return [::String] # The SELECT query which returns rows which this relation should contain. # @!attribute [rw] pre_operations # @return [::Array<::String>] # SQL statements to be executed before creating the relation. # @!attribute [rw] post_operations # @return [::Array<::String>] # SQL statements to be executed after creating the relation. # @!attribute [rw] incremental_table_config # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig] # Configures `INCREMENTAL_TABLE` settings for this relation. Only set if # `relation_type` is `INCREMENTAL_TABLE`. # @!attribute [rw] partition_expression # @return [::String] # The SQL expression used to partition the relation. # @!attribute [rw] cluster_expressions # @return [::Array<::String>] # A list of columns or SQL expressions used to cluster the table. # @!attribute [rw] partition_expiration_days # @return [::Integer] # Sets the partition expiration in days. # @!attribute [rw] require_partition_filter # @return [::Boolean] # Specifies whether queries on this table must include a predicate filter # that filters on the partitioning column. # @!attribute [rw] additional_options # @return [::Google::Protobuf::Map{::String => ::String}] # Additional options that will be provided as key/value pairs into the # options clause of a create table/view statement. See # https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language # for more information on which options are supported. class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end end # Represents a list of arbitrary database operations. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for any output relation and its columns. Only set if # `has_output` is true. # @!attribute [rw] queries # @return [::Array<::String>] # A list of arbitrary SQL statements that will be executed without # alteration. # @!attribute [rw] has_output # @return [::Boolean] # Whether these operations produce an output relation. class Operations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents an assertion upon a SQL query which is required return zero # rows. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] parent_action # @return [::Google::Cloud::Dataform::V1beta1::Target] # The parent action of this assertion. Only set if this assertion was # automatically generated. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] select_query # @return [::String] # The SELECT query which must return zero rows in order for this assertion # to succeed. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the assertion's automatically-generated view and its # columns. class Assertion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a relation which is not managed by Dataform but which may be # referenced by Dataform actions. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. Used as documentation only, # i.e. values here will result in no changes to the relation's metadata. class Declaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#declaration ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Declaration
Returns The declaration declared by this action.
882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 882 class CompilationResultAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a database relation. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. # @!attribute [rw] relation_type # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType] # The type of this relation. # @!attribute [rw] select_query # @return [::String] # The SELECT query which returns rows which this relation should contain. # @!attribute [rw] pre_operations # @return [::Array<::String>] # SQL statements to be executed before creating the relation. # @!attribute [rw] post_operations # @return [::Array<::String>] # SQL statements to be executed after creating the relation. # @!attribute [rw] incremental_table_config # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig] # Configures `INCREMENTAL_TABLE` settings for this relation. Only set if # `relation_type` is `INCREMENTAL_TABLE`. # @!attribute [rw] partition_expression # @return [::String] # The SQL expression used to partition the relation. # @!attribute [rw] cluster_expressions # @return [::Array<::String>] # A list of columns or SQL expressions used to cluster the table. # @!attribute [rw] partition_expiration_days # @return [::Integer] # Sets the partition expiration in days. # @!attribute [rw] require_partition_filter # @return [::Boolean] # Specifies whether queries on this table must include a predicate filter # that filters on the partitioning column. # @!attribute [rw] additional_options # @return [::Google::Protobuf::Map{::String => ::String}] # Additional options that will be provided as key/value pairs into the # options clause of a create table/view statement. See # https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language # for more information on which options are supported. class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end end # Represents a list of arbitrary database operations. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for any output relation and its columns. Only set if # `has_output` is true. # @!attribute [rw] queries # @return [::Array<::String>] # A list of arbitrary SQL statements that will be executed without # alteration. # @!attribute [rw] has_output # @return [::Boolean] # Whether these operations produce an output relation. class Operations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents an assertion upon a SQL query which is required return zero # rows. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] parent_action # @return [::Google::Cloud::Dataform::V1beta1::Target] # The parent action of this assertion. Only set if this assertion was # automatically generated. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] select_query # @return [::String] # The SELECT query which must return zero rows in order for this assertion # to succeed. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the assertion's automatically-generated view and its # columns. class Assertion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a relation which is not managed by Dataform but which may be # referenced by Dataform actions. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. Used as documentation only, # i.e. values here will result in no changes to the relation's metadata. class Declaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#file_path ⇒ ::String
Returns The full path including filename in which this action is located, relative to the workspace root.
882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 882 class CompilationResultAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a database relation. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. # @!attribute [rw] relation_type # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType] # The type of this relation. # @!attribute [rw] select_query # @return [::String] # The SELECT query which returns rows which this relation should contain. # @!attribute [rw] pre_operations # @return [::Array<::String>] # SQL statements to be executed before creating the relation. # @!attribute [rw] post_operations # @return [::Array<::String>] # SQL statements to be executed after creating the relation. # @!attribute [rw] incremental_table_config # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig] # Configures `INCREMENTAL_TABLE` settings for this relation. Only set if # `relation_type` is `INCREMENTAL_TABLE`. # @!attribute [rw] partition_expression # @return [::String] # The SQL expression used to partition the relation. # @!attribute [rw] cluster_expressions # @return [::Array<::String>] # A list of columns or SQL expressions used to cluster the table. # @!attribute [rw] partition_expiration_days # @return [::Integer] # Sets the partition expiration in days. # @!attribute [rw] require_partition_filter # @return [::Boolean] # Specifies whether queries on this table must include a predicate filter # that filters on the partitioning column. # @!attribute [rw] additional_options # @return [::Google::Protobuf::Map{::String => ::String}] # Additional options that will be provided as key/value pairs into the # options clause of a create table/view statement. See # https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language # for more information on which options are supported. class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end end # Represents a list of arbitrary database operations. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for any output relation and its columns. Only set if # `has_output` is true. # @!attribute [rw] queries # @return [::Array<::String>] # A list of arbitrary SQL statements that will be executed without # alteration. # @!attribute [rw] has_output # @return [::Boolean] # Whether these operations produce an output relation. class Operations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents an assertion upon a SQL query which is required return zero # rows. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] parent_action # @return [::Google::Cloud::Dataform::V1beta1::Target] # The parent action of this assertion. Only set if this assertion was # automatically generated. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] select_query # @return [::String] # The SELECT query which must return zero rows in order for this assertion # to succeed. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the assertion's automatically-generated view and its # columns. class Assertion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a relation which is not managed by Dataform but which may be # referenced by Dataform actions. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. Used as documentation only, # i.e. values here will result in no changes to the relation's metadata. class Declaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#operations ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Operations
Returns The database operations executed by this action.
882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 882 class CompilationResultAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a database relation. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. # @!attribute [rw] relation_type # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType] # The type of this relation. # @!attribute [rw] select_query # @return [::String] # The SELECT query which returns rows which this relation should contain. # @!attribute [rw] pre_operations # @return [::Array<::String>] # SQL statements to be executed before creating the relation. # @!attribute [rw] post_operations # @return [::Array<::String>] # SQL statements to be executed after creating the relation. # @!attribute [rw] incremental_table_config # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig] # Configures `INCREMENTAL_TABLE` settings for this relation. Only set if # `relation_type` is `INCREMENTAL_TABLE`. # @!attribute [rw] partition_expression # @return [::String] # The SQL expression used to partition the relation. # @!attribute [rw] cluster_expressions # @return [::Array<::String>] # A list of columns or SQL expressions used to cluster the table. # @!attribute [rw] partition_expiration_days # @return [::Integer] # Sets the partition expiration in days. # @!attribute [rw] require_partition_filter # @return [::Boolean] # Specifies whether queries on this table must include a predicate filter # that filters on the partitioning column. # @!attribute [rw] additional_options # @return [::Google::Protobuf::Map{::String => ::String}] # Additional options that will be provided as key/value pairs into the # options clause of a create table/view statement. See # https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language # for more information on which options are supported. class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end end # Represents a list of arbitrary database operations. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for any output relation and its columns. Only set if # `has_output` is true. # @!attribute [rw] queries # @return [::Array<::String>] # A list of arbitrary SQL statements that will be executed without # alteration. # @!attribute [rw] has_output # @return [::Boolean] # Whether these operations produce an output relation. class Operations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents an assertion upon a SQL query which is required return zero # rows. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] parent_action # @return [::Google::Cloud::Dataform::V1beta1::Target] # The parent action of this assertion. Only set if this assertion was # automatically generated. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] select_query # @return [::String] # The SELECT query which must return zero rows in order for this assertion # to succeed. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the assertion's automatically-generated view and its # columns. class Assertion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a relation which is not managed by Dataform but which may be # referenced by Dataform actions. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. Used as documentation only, # i.e. values here will result in no changes to the relation's metadata. class Declaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#relation ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation
Returns The database relation created/updated by this action.
882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 882 class CompilationResultAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a database relation. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. # @!attribute [rw] relation_type # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType] # The type of this relation. # @!attribute [rw] select_query # @return [::String] # The SELECT query which returns rows which this relation should contain. # @!attribute [rw] pre_operations # @return [::Array<::String>] # SQL statements to be executed before creating the relation. # @!attribute [rw] post_operations # @return [::Array<::String>] # SQL statements to be executed after creating the relation. # @!attribute [rw] incremental_table_config # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig] # Configures `INCREMENTAL_TABLE` settings for this relation. Only set if # `relation_type` is `INCREMENTAL_TABLE`. # @!attribute [rw] partition_expression # @return [::String] # The SQL expression used to partition the relation. # @!attribute [rw] cluster_expressions # @return [::Array<::String>] # A list of columns or SQL expressions used to cluster the table. # @!attribute [rw] partition_expiration_days # @return [::Integer] # Sets the partition expiration in days. # @!attribute [rw] require_partition_filter # @return [::Boolean] # Specifies whether queries on this table must include a predicate filter # that filters on the partitioning column. # @!attribute [rw] additional_options # @return [::Google::Protobuf::Map{::String => ::String}] # Additional options that will be provided as key/value pairs into the # options clause of a create table/view statement. See # https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language # for more information on which options are supported. class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end end # Represents a list of arbitrary database operations. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for any output relation and its columns. Only set if # `has_output` is true. # @!attribute [rw] queries # @return [::Array<::String>] # A list of arbitrary SQL statements that will be executed without # alteration. # @!attribute [rw] has_output # @return [::Boolean] # Whether these operations produce an output relation. class Operations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents an assertion upon a SQL query which is required return zero # rows. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] parent_action # @return [::Google::Cloud::Dataform::V1beta1::Target] # The parent action of this assertion. Only set if this assertion was # automatically generated. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] select_query # @return [::String] # The SELECT query which must return zero rows in order for this assertion # to succeed. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the assertion's automatically-generated view and its # columns. class Assertion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a relation which is not managed by Dataform but which may be # referenced by Dataform actions. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. Used as documentation only, # i.e. values here will result in no changes to the relation's metadata. class Declaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#target ⇒ ::Google::Cloud::Dataform::V1beta1::Target
Returns This action's identifier. Unique within the compilation result.
882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 882 class CompilationResultAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a database relation. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. # @!attribute [rw] relation_type # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType] # The type of this relation. # @!attribute [rw] select_query # @return [::String] # The SELECT query which returns rows which this relation should contain. # @!attribute [rw] pre_operations # @return [::Array<::String>] # SQL statements to be executed before creating the relation. # @!attribute [rw] post_operations # @return [::Array<::String>] # SQL statements to be executed after creating the relation. # @!attribute [rw] incremental_table_config # @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig] # Configures `INCREMENTAL_TABLE` settings for this relation. Only set if # `relation_type` is `INCREMENTAL_TABLE`. # @!attribute [rw] partition_expression # @return [::String] # The SQL expression used to partition the relation. # @!attribute [rw] cluster_expressions # @return [::Array<::String>] # A list of columns or SQL expressions used to cluster the table. # @!attribute [rw] partition_expiration_days # @return [::Integer] # Sets the partition expiration in days. # @!attribute [rw] require_partition_filter # @return [::Boolean] # Specifies whether queries on this table must include a predicate filter # that filters on the partitioning column. # @!attribute [rw] additional_options # @return [::Google::Protobuf::Map{::String => ::String}] # Additional options that will be provided as key/value pairs into the # options clause of a create table/view statement. See # https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language # for more information on which options are supported. class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end end # Represents a list of arbitrary database operations. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for any output relation and its columns. Only set if # `has_output` is true. # @!attribute [rw] queries # @return [::Array<::String>] # A list of arbitrary SQL statements that will be executed without # alteration. # @!attribute [rw] has_output # @return [::Boolean] # Whether these operations produce an output relation. class Operations include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents an assertion upon a SQL query which is required return zero # rows. # @!attribute [rw] dependency_targets # @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>] # A list of actions that this action depends on. # @!attribute [rw] parent_action # @return [::Google::Cloud::Dataform::V1beta1::Target] # The parent action of this assertion. Only set if this assertion was # automatically generated. # @!attribute [rw] disabled # @return [::Boolean] # Whether this action is disabled (i.e. should not be run). # @!attribute [rw] tags # @return [::Array<::String>] # Arbitrary, user-defined tags on this action. # @!attribute [rw] select_query # @return [::String] # The SELECT query which must return zero rows in order for this assertion # to succeed. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the assertion's automatically-generated view and its # columns. class Assertion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents a relation which is not managed by Dataform but which may be # referenced by Dataform actions. # @!attribute [rw] relation_descriptor # @return [::Google::Cloud::Dataform::V1beta1::RelationDescriptor] # Descriptor for the relation and its columns. Used as documentation only, # i.e. values here will result in no changes to the relation's metadata. class Declaration include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |