Class: Google::Cloud::Dataform::V1beta1::CompilationResultAction::DataPreparation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Defines a compiled Data Preparation entity

Defined Under Namespace

Classes: ErrorTable, SqlDefinition

Instance Attribute Summary collapse

Instance Attribute Details

#contents_sql::Google::Cloud::Dataform::V1beta1::CompilationResultAction::DataPreparation::SqlDefinition

Returns SQL definition for a Data Preparation. Contains a SQL query and additional context information.

Note: The following fields are mutually exclusive: contents_sql, contents_yaml. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2137

class DataPreparation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Definition of a SQL Data Preparation
  # @!attribute [rw] query
  #   @return [::String]
  #     The SQL query representing the data preparation steps. Formatted as a
  #     Pipe SQL query statement.
  # @!attribute [rw] error_table
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::DataPreparation::ErrorTable]
  #     Error table configuration,
  # @!attribute [rw] load
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::LoadConfig]
  #     Load configuration.
  class SqlDefinition
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Error table information, used to write error data into a BigQuery
  # table.
  # @!attribute [rw] target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Error Table target.
  # @!attribute [rw] retention_days
  #   @return [::Integer]
  #     Error table partition expiration in days. Only positive values are
  #     allowed.
  class ErrorTable
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#contents_yaml::String

Returns The data preparation definition, stored as a YAML string.

Note: The following fields are mutually exclusive: contents_yaml, contents_sql. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The data preparation definition, stored as a YAML string.

    Note: The following fields are mutually exclusive: contents_yaml, contents_sql. If a field in that set is populated, all other fields in the set will automatically be cleared.



2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2137

class DataPreparation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Definition of a SQL Data Preparation
  # @!attribute [rw] query
  #   @return [::String]
  #     The SQL query representing the data preparation steps. Formatted as a
  #     Pipe SQL query statement.
  # @!attribute [rw] error_table
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::DataPreparation::ErrorTable]
  #     Error table configuration,
  # @!attribute [rw] load
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::LoadConfig]
  #     Load configuration.
  class SqlDefinition
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Error table information, used to write error data into a BigQuery
  # table.
  # @!attribute [rw] target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Error Table target.
  # @!attribute [rw] retention_days
  #   @return [::Integer]
  #     Error table partition expiration in days. Only positive values are
  #     allowed.
  class ErrorTable
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#dependency_targets::Array<::Google::Cloud::Dataform::V1beta1::Target>

Returns A list of actions that this action depends on.

Returns:



2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2137

class DataPreparation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Definition of a SQL Data Preparation
  # @!attribute [rw] query
  #   @return [::String]
  #     The SQL query representing the data preparation steps. Formatted as a
  #     Pipe SQL query statement.
  # @!attribute [rw] error_table
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::DataPreparation::ErrorTable]
  #     Error table configuration,
  # @!attribute [rw] load
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::LoadConfig]
  #     Load configuration.
  class SqlDefinition
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Error table information, used to write error data into a BigQuery
  # table.
  # @!attribute [rw] target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Error Table target.
  # @!attribute [rw] retention_days
  #   @return [::Integer]
  #     Error table partition expiration in days. Only positive values are
  #     allowed.
  class ErrorTable
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#disabled::Boolean

Returns Whether this action is disabled (i.e. should not be run).

Returns:

  • (::Boolean)

    Whether this action is disabled (i.e. should not be run).



2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2137

class DataPreparation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Definition of a SQL Data Preparation
  # @!attribute [rw] query
  #   @return [::String]
  #     The SQL query representing the data preparation steps. Formatted as a
  #     Pipe SQL query statement.
  # @!attribute [rw] error_table
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::DataPreparation::ErrorTable]
  #     Error table configuration,
  # @!attribute [rw] load
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::LoadConfig]
  #     Load configuration.
  class SqlDefinition
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Error table information, used to write error data into a BigQuery
  # table.
  # @!attribute [rw] target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Error Table target.
  # @!attribute [rw] retention_days
  #   @return [::Integer]
  #     Error table partition expiration in days. Only positive values are
  #     allowed.
  class ErrorTable
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#tags::Array<::String>

Returns Arbitrary, user-defined tags on this action.

Returns:

  • (::Array<::String>)

    Arbitrary, user-defined tags on this action.



2137
2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2137

class DataPreparation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Definition of a SQL Data Preparation
  # @!attribute [rw] query
  #   @return [::String]
  #     The SQL query representing the data preparation steps. Formatted as a
  #     Pipe SQL query statement.
  # @!attribute [rw] error_table
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::DataPreparation::ErrorTable]
  #     Error table configuration,
  # @!attribute [rw] load
  #   @return [::Google::Cloud::Dataform::V1beta1::CompilationResultAction::LoadConfig]
  #     Load configuration.
  class SqlDefinition
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Error table information, used to write error data into a BigQuery
  # table.
  # @!attribute [rw] target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Error Table target.
  # @!attribute [rw] retention_days
  #   @return [::Integer]
  #     Error table partition expiration in days. Only positive values are
  #     allowed.
  class ErrorTable
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end