Class: Google::Cloud::Dataform::V1beta1::Config
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::Config
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Config for all repositories in a given project and location.
Instance Attribute Summary collapse
-
#default_kms_key_name ⇒ ::String
Optional.
-
#internal_metadata ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
Instance Attribute Details
#default_kms_key_name ⇒ ::String
Returns Optional. The default KMS key that is used if no encryption key is provided when a repository is created.
2656 2657 2658 2659 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2656 class Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#internal_metadata ⇒ ::String (readonly)
Returns Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
2656 2657 2658 2659 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2656 class Config include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |