Class: Google::Cloud::Dataform::V1beta1::DeleteFolderTreeMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::DeleteFolderTreeMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Contains metadata about the progress of the DeleteFolderTree Long-running operations.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#percent_complete ⇒ ::Integer
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Dataform::V1beta1::DeleteFolderTreeMetadata::State
readonly
Output only.
-
#target ⇒ ::String
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation was created.
3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 3099 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3077 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation finished running.
3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 3099 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3077 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |
#percent_complete ⇒ ::Integer (readonly)
Returns Output only. Percent complete of the operation [0, 100].
3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 3099 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3077 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |
#state ⇒ ::Google::Cloud::Dataform::V1beta1::DeleteFolderTreeMetadata::State (readonly)
Returns Output only. The state of the operation.
3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 3099 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3077 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |
#target ⇒ ::String (readonly)
Returns Output only. Resource name of the target of the operation. Format: projects/{project}/locations/{location}/folders/{folder} or projects/{project}/locations/{location}/teamFolders/{team_folder}.
3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 3096 3097 3098 3099 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3077 class DeleteFolderTreeMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteFolderTree operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation was initialized and recorded by the server, but not yet # started. INITIALIZED = 1 # The operation is in progress. IN_PROGRESS = 2 # The operation has completed successfully. SUCCEEDED = 3 # The operation has failed. FAILED = 4 end end |