Class: Google::Cloud::Dataform::V1beta1::DeleteRepositoryRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

DeleteRepository request message.

Instance Attribute Summary collapse

Instance Attribute Details

#force::Boolean

Returns Optional. If set to true, child resources of this repository (compilation results and workflow invocations) will also be deleted. Otherwise, the request will only succeed if the repository has no child resources.

Note: This flag doesn't support deletion of workspaces, release configs or workflow configs. If any of such resources exists in the repository, the request will fail..

Returns:

  • (::Boolean)

    Optional. If set to true, child resources of this repository (compilation results and workflow invocations) will also be deleted. Otherwise, the request will only succeed if the repository has no child resources.

    Note: This flag doesn't support deletion of workspaces, release configs or workflow configs. If any of such resources exists in the repository, the request will fail..



318
319
320
321
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 318

class DeleteRepositoryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The repository's name.

Returns:

  • (::String)

    Required. The repository's name.



318
319
320
321
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 318

class DeleteRepositoryRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end