Class: Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents the Git state of a file with uncommitted changes.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#path::String

Returns The file's full path including filename, relative to the workspace root.

Returns:

  • (::String)

    The file's full path including filename, relative to the workspace root.



808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 808

class UncommittedFileChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the status of an uncommitted file change.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The file has been newly added.
    ADDED = 1

    # The file has been deleted.
    DELETED = 2

    # The file has been modified.
    MODIFIED = 3

    # The file contains merge conflicts.
    HAS_CONFLICTS = 4
  end
end

#state::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange::State (readonly)

Returns Output only. Indicates the status of the file.

Returns:



808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 808

class UncommittedFileChange
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the status of an uncommitted file change.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The file has been newly added.
    ADDED = 1

    # The file has been deleted.
    DELETED = 2

    # The file has been modified.
    MODIFIED = 3

    # The file contains merge conflicts.
    HAS_CONFLICTS = 4
  end
end