Class: Google::Cloud::Dataform::V1beta1::FetchRepositoryHistoryRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::FetchRepositoryHistoryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
FetchRepositoryHistory request message.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The repository's name.
397 398 399 400 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 397 class FetchRepositoryHistoryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Maximum number of commits to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
397 398 399 400 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 397 class FetchRepositoryHistoryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Page token received from a previous FetchRepositoryHistory
call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to FetchRepositoryHistory
must match the call that provided the page token.
397 398 399 400 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 397 class FetchRepositoryHistoryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |