Class: Google::Cloud::Dataform::V1beta1::FileSearchResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::FileSearchResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Client-facing representation of a file entry in search results.
Instance Attribute Summary collapse
-
#path ⇒ ::String
File system path relative to the workspace root.
Instance Attribute Details
#path ⇒ ::String
Returns File system path relative to the workspace root.
1004 1005 1006 1007 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1004 class FileSearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |