Class: Google::Cloud::Dataform::V1beta1::InvocationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Includes various configuration options for a workflow invocation. If both included_targets and included_tags are unset, all actions will be included.

Defined Under Namespace

Modules: QueryPriority

Instance Attribute Summary collapse

Instance Attribute Details

#fully_refresh_incremental_tables_enabled::Boolean

Returns Optional. When set to true, any incremental tables will be fully refreshed.

Returns:

  • (::Boolean)

    Optional. When set to true, any incremental tables will be fully refreshed.



2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2357

class InvocationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of priority for query execution in BigQuery.
  module QueryPriority
    # Default value. This value is unused.
    QUERY_PRIORITY_UNSPECIFIED = 0

    # Query will be executed in BigQuery with interactive priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#queries.
    INTERACTIVE = 1

    # Query will be executed in BigQuery with batch priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#batchqueries.
    BATCH = 2
  end
end

#included_tags::Array<::String>

Returns Optional. The set of tags to include.

Returns:

  • (::Array<::String>)

    Optional. The set of tags to include.



2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2357

class InvocationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of priority for query execution in BigQuery.
  module QueryPriority
    # Default value. This value is unused.
    QUERY_PRIORITY_UNSPECIFIED = 0

    # Query will be executed in BigQuery with interactive priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#queries.
    INTERACTIVE = 1

    # Query will be executed in BigQuery with batch priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#batchqueries.
    BATCH = 2
  end
end

#included_targets::Array<::Google::Cloud::Dataform::V1beta1::Target>

Returns Optional. The set of action identifiers to include.

Returns:



2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2357

class InvocationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of priority for query execution in BigQuery.
  module QueryPriority
    # Default value. This value is unused.
    QUERY_PRIORITY_UNSPECIFIED = 0

    # Query will be executed in BigQuery with interactive priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#queries.
    INTERACTIVE = 1

    # Query will be executed in BigQuery with batch priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#batchqueries.
    BATCH = 2
  end
end

#query_priority::Google::Cloud::Dataform::V1beta1::InvocationConfig::QueryPriority

Returns Optional. Specifies the priority for query execution in BigQuery. More information can be found at https://cloud.google.com/bigquery/docs/running-queries#queries.

Returns:



2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2357

class InvocationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of priority for query execution in BigQuery.
  module QueryPriority
    # Default value. This value is unused.
    QUERY_PRIORITY_UNSPECIFIED = 0

    # Query will be executed in BigQuery with interactive priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#queries.
    INTERACTIVE = 1

    # Query will be executed in BigQuery with batch priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#batchqueries.
    BATCH = 2
  end
end

#service_account::String

Returns Optional. The service account to run workflow invocations under.

Returns:

  • (::String)

    Optional. The service account to run workflow invocations under.



2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2357

class InvocationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of priority for query execution in BigQuery.
  module QueryPriority
    # Default value. This value is unused.
    QUERY_PRIORITY_UNSPECIFIED = 0

    # Query will be executed in BigQuery with interactive priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#queries.
    INTERACTIVE = 1

    # Query will be executed in BigQuery with batch priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#batchqueries.
    BATCH = 2
  end
end

#transitive_dependencies_included::Boolean

Returns Optional. When set to true, transitive dependencies of included actions will be executed.

Returns:

  • (::Boolean)

    Optional. When set to true, transitive dependencies of included actions will be executed.



2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2357

class InvocationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of priority for query execution in BigQuery.
  module QueryPriority
    # Default value. This value is unused.
    QUERY_PRIORITY_UNSPECIFIED = 0

    # Query will be executed in BigQuery with interactive priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#queries.
    INTERACTIVE = 1

    # Query will be executed in BigQuery with batch priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#batchqueries.
    BATCH = 2
  end
end

#transitive_dependents_included::Boolean

Returns Optional. When set to true, transitive dependents of included actions will be executed.

Returns:

  • (::Boolean)

    Optional. When set to true, transitive dependents of included actions will be executed.



2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2357

class InvocationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Types of priority for query execution in BigQuery.
  module QueryPriority
    # Default value. This value is unused.
    QUERY_PRIORITY_UNSPECIFIED = 0

    # Query will be executed in BigQuery with interactive priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#queries.
    INTERACTIVE = 1

    # Query will be executed in BigQuery with batch priority.
    # More information can be found at
    # https://cloud.google.com/bigquery/docs/running-queries#batchqueries.
    BATCH = 2
  end
end