Class: Google::Cloud::Dataform::V1beta1::ListRepositoriesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

ListRepositories request message.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Filter for the returned list.

Returns:

  • (::String)

    Optional. Filter for the returned list.



97
98
99
100
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 97

class ListRepositoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. This field only supports ordering by name. If unspecified, the server will choose the ordering. If specified, the default order is ascending for the name field.

Returns:

  • (::String)

    Optional. This field only supports ordering by name. If unspecified, the server will choose the ordering. If specified, the default order is ascending for the name field.



97
98
99
100
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 97

class ListRepositoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Maximum number of repositories to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Maximum number of repositories to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.



97
98
99
100
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 97

class ListRepositoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Page token received from a previous ListRepositories call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListRepositories must match the call that provided the page token.

Returns:

  • (::String)

    Optional. Page token received from a previous ListRepositories call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListRepositories must match the call that provided the page token.



97
98
99
100
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 97

class ListRepositoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The location in which to list repositories. Must be in the format projects/*/locations/*.

Returns:

  • (::String)

    Required. The location in which to list repositories. Must be in the format projects/*/locations/*.



97
98
99
100
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 97

class ListRepositoriesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end