Class: Google::Cloud::Dataform::V1beta1::ListWorkflowInvocationsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

ListWorkflowInvocations request message.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. Maximum number of workflow invocations to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Maximum number of workflow invocations to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.



1189
1190
1191
1192
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1189

class ListWorkflowInvocationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Page token received from a previous ListWorkflowInvocations call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListWorkflowInvocations must match the call that provided the page token.

Returns:

  • (::String)

    Optional. Page token received from a previous ListWorkflowInvocations call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListWorkflowInvocations must match the call that provided the page token.



1189
1190
1191
1192
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1189

class ListWorkflowInvocationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource of the WorkflowInvocation type. Must be in the format projects/*/locations/*/repositories/*.

Returns:

  • (::String)

    Required. The parent resource of the WorkflowInvocation type. Must be in the format projects/*/locations/*/repositories/*.



1189
1190
1191
1192
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1189

class ListWorkflowInvocationsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end