Class: Google::Cloud::Dataform::V1beta1::ListWorkspacesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::ListWorkspacesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
ListWorkspaces request message.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filter for the returned list.
223 224 225 226 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 223 class ListWorkspacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. This field only supports ordering by name. If unspecified, the server
will choose the ordering. If specified, the default order is ascending for
the name field.
223 224 225 226 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 223 class ListWorkspacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Maximum number of workspaces to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
223 224 225 226 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 223 class ListWorkspacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Page token received from a previous ListWorkspaces call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListWorkspaces
must match the call that provided the page token.
223 224 225 226 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 223 class ListWorkspacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The repository in which to list workspaces. Must be in the
format projects/*/locations/*/repositories/*.
223 224 225 226 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 223 class ListWorkspacesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |