Class: Google::Cloud::Dataform::V1beta1::MoveFolderRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

MoveFolder request message.

Instance Attribute Summary collapse

Instance Attribute Details

#destination_containing_folder::String

Returns Optional. The name of the Folder, TeamFolder, or root location to move the Folder to. Can be in the format of: "" to move into the root User folder, projects/*/locations/*/folders/*, projects/*/locations/*/teamFolders/*.

Returns:

  • (::String)

    Optional. The name of the Folder, TeamFolder, or root location to move the Folder to. Can be in the format of: "" to move into the root User folder, projects/*/locations/*/folders/*, projects/*/locations/*/teamFolders/*



2749
2750
2751
2752
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2749

class MoveFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The full resource name of the Folder to move.

Returns:

  • (::String)

    Required. The full resource name of the Folder to move.



2749
2750
2751
2752
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2749

class MoveFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end