Class: Google::Cloud::Dataform::V1beta1::NotebookRuntimeOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Configures various aspects of Dataform notebook runtime.

Instance Attribute Summary collapse

Instance Attribute Details

#ai_platform_notebook_runtime_template::String

Returns Optional. The resource name of the Colab runtime template, from which a runtime is created for notebook executions. If not specified, a runtime is created with Colab's default specifications.

Returns:

  • (::String)

    Optional. The resource name of the Colab runtime template, from which a runtime is created for notebook executions. If not specified, a runtime is created with Colab's default specifications.



1674
1675
1676
1677
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1674

class NotebookRuntimeOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gcs_output_bucket::String

Returns Optional. The Google Cloud Storage location to upload the result to. Format: gs://bucket-name.

Returns:

  • (::String)

    Optional. The Google Cloud Storage location to upload the result to. Format: gs://bucket-name.



1674
1675
1676
1677
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1674

class NotebookRuntimeOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gcs_repository_snapshot_destination::Google::Cloud::Dataform::V1beta1::GcsRepositorySnapshotDestination

Returns Optional. The Google Cloud Storage destination to upload the snapshot to. For empty URI it defaults to the provided gcs_output_bucket. Format: gs://bucket-name/path/.

Returns:



1674
1675
1676
1677
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1674

class NotebookRuntimeOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end