Class: Google::Cloud::Dataform::V1beta1::PipelineConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Defines the pipeline type and path within the Git repository.

Defined Under Namespace

Modules: PipelineType

Instance Attribute Summary collapse

Instance Attribute Details

#path::String

Returns Required. The relative path within the Git repository where the pipeline is defined. For example, for a Dataform pipeline, it is a path to the folder where workflow_settings.yaml or dataform.json is located.

Returns:

  • (::String)

    Required. The relative path within the Git repository where the pipeline is defined. For example, for a Dataform pipeline, it is a path to the folder where workflow_settings.yaml or dataform.json is located.



1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1688

class PipelineConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the pipeline. This may be extended in the future.
  # In case of UNSPECIFIED, the error will be thrown.
  module PipelineType
    # Default value. This value is unused.
    PIPELINE_TYPE_UNSPECIFIED = 0

    # Regular Dataform pipeline.
    DATAFORM = 1

    # SQL single file asset.
    SQL = 3

    # Notebook single file asset.
    NOTEBOOK = 4
  end
end

#pipeline_type::Google::Cloud::Dataform::V1beta1::PipelineConfig::PipelineType

Returns Required. The type of the pipeline.

Returns:



1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1688

class PipelineConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of the pipeline. This may be extended in the future.
  # In case of UNSPECIFIED, the error will be thrown.
  module PipelineType
    # Default value. This value is unused.
    PIPELINE_TYPE_UNSPECIFIED = 0

    # Regular Dataform pipeline.
    DATAFORM = 1

    # SQL single file asset.
    SQL = 3

    # Notebook single file asset.
    NOTEBOOK = 4
  end
end