Class: Google::Cloud::Dataform::V1beta1::QueryFolderContentsResponse::FolderContentsEntry

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents a single content entry.

Instance Attribute Summary collapse

Instance Attribute Details

#folder::Google::Cloud::Dataform::V1beta1::Folder

Returns A subfolder.

Note: The following fields are mutually exclusive: folder, repository. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataform::V1beta1::Folder)

    A subfolder.

    Note: The following fields are mutually exclusive: folder, repository. If a field in that set is populated, all other fields in the set will automatically be cleared.



2849
2850
2851
2852
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2849

class FolderContentsEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#repository::Google::Cloud::Dataform::V1beta1::Repository

Returns A repository.

Note: The following fields are mutually exclusive: repository, folder. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Dataform::V1beta1::Repository)

    A repository.

    Note: The following fields are mutually exclusive: repository, folder. If a field in that set is populated, all other fields in the set will automatically be cleared.



2849
2850
2851
2852
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2849

class FolderContentsEntry
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end