Class: Google::Cloud::Dataform::V1beta1::QueryRepositoryDirectoryContentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::QueryRepositoryDirectoryContentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
QueryRepositoryDirectoryContents request message.
Instance Attribute Summary collapse
-
#commit_sha ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#path ⇒ ::String
Optional.
Instance Attribute Details
#commit_sha ⇒ ::String
Returns Optional. The Commit SHA for the commit to query from. If unset, the directory will be queried from HEAD.
363 364 365 366 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 363 class QueryRepositoryDirectoryContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The repository's name.
363 364 365 366 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 363 class QueryRepositoryDirectoryContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
363 364 365 366 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 363 class QueryRepositoryDirectoryContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Page token received from a previous
QueryRepositoryDirectoryContents call. Provide this to retrieve the
subsequent page.
When paginating, all other parameters provided to
QueryRepositoryDirectoryContents must match the call that provided the
page token.
363 364 365 366 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 363 class QueryRepositoryDirectoryContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#path ⇒ ::String
Returns Optional. The directory's full path including directory name, relative to root. If left unset, the root is used.
363 364 365 366 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 363 class QueryRepositoryDirectoryContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |