Class: Google::Cloud::Dataform::V1beta1::QueryTeamFolderContentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

QueryTeamFolderContents request message.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Optional filtering for the returned list. Filtering is currently only supported on the display_name field.

Example:

  • filter="display_name="MyFolder"".

Returns:

  • (::String)

    Optional. Optional filtering for the returned list. Filtering is currently only supported on the display_name field.

    Example:

    • filter="display_name="MyFolder""


3032
3033
3034
3035
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3032

class QueryTeamFolderContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Field to additionally sort results by. Will order Folders before Repositories, and then by order_by in ascending order. Supported keywords: display_name (default), create_time, last_modified_time. Examples:

  • orderBy="display_name"
  • orderBy="display_name desc".

Returns:

  • (::String)

    Optional. Field to additionally sort results by. Will order Folders before Repositories, and then by order_by in ascending order. Supported keywords: display_name (default), create_time, last_modified_time. Examples:

    • orderBy="display_name"
    • orderBy="display_name desc"


3032
3033
3034
3035
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3032

class QueryTeamFolderContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.



3032
3033
3034
3035
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3032

class QueryTeamFolderContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Page token received from a previous QueryTeamFolderContents call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to QueryTeamFolderContents, with the exception of page_size, must match the call that provided the page token.

Returns:

  • (::String)

    Optional. Page token received from a previous QueryTeamFolderContents call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to QueryTeamFolderContents, with the exception of page_size, must match the call that provided the page token.



3032
3033
3034
3035
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3032

class QueryTeamFolderContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#team_folder::String

Returns Required. Name of the team_folder whose contents to list. Format: projects/*/locations/*/teamFolders/*.

Returns:

  • (::String)

    Required. Name of the team_folder whose contents to list. Format: projects/*/locations/*/teamFolders/*.



3032
3033
3034
3035
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3032

class QueryTeamFolderContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end