Class: Google::Cloud::Dataform::V1beta1::QueryUserRootContentsResponse::RootContentsEntry
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::QueryUserRootContentsResponse::RootContentsEntry
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a single content entry.
Instance Attribute Summary collapse
-
#folder ⇒ ::Google::Cloud::Dataform::V1beta1::Folder
A subfolder.
-
#repository ⇒ ::Google::Cloud::Dataform::V1beta1::Repository
A repository.
Instance Attribute Details
#folder ⇒ ::Google::Cloud::Dataform::V1beta1::Folder
Returns A subfolder.
Note: The following fields are mutually exclusive: folder, repository. If a field in that set is populated, all other fields in the set will automatically be cleared.
2916 2917 2918 2919 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2916 class RootContentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#repository ⇒ ::Google::Cloud::Dataform::V1beta1::Repository
Returns A repository.
Note: The following fields are mutually exclusive: repository, folder. If a field in that set is populated, all other fields in the set will automatically be cleared.
2916 2917 2918 2919 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2916 class RootContentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |