Class: Google::Cloud::Dataform::V1beta1::ReleaseConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::ReleaseConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a Dataform release configuration.
Defined Under Namespace
Classes: ScheduledReleaseRecord
Instance Attribute Summary collapse
-
#code_compilation_config ⇒ ::Google::Cloud::Dataform::V1beta1::CodeCompilationConfig
Optional.
-
#cron_schedule ⇒ ::String
Optional.
-
#disabled ⇒ ::Boolean
Optional.
-
#git_commitish ⇒ ::String
Required.
-
#internal_metadata ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#recent_scheduled_release_records ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::ReleaseConfig::ScheduledReleaseRecord>
readonly
Output only.
-
#release_compilation_result ⇒ ::String
Optional.
-
#time_zone ⇒ ::String
Optional.
Instance Attribute Details
#code_compilation_config ⇒ ::Google::Cloud::Dataform::V1beta1::CodeCompilationConfig
Returns Optional. If set, fields of code_compilation_config override the default
compilation settings that are specified in dataform.json.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1230 class ReleaseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a compilation result for this release # config. # @!attribute [rw] compilation_result # @return [::String] # The name of the created compilation result, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/compilationResults/*`. # # Note: The following fields are mutually exclusive: `compilation_result`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # compilation result, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `compilation_result`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] release_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this release attempt. class ScheduledReleaseRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#cron_schedule ⇒ ::String
Returns Optional. Optional schedule (in cron format) for automatic creation of compilation results.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1230 class ReleaseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a compilation result for this release # config. # @!attribute [rw] compilation_result # @return [::String] # The name of the created compilation result, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/compilationResults/*`. # # Note: The following fields are mutually exclusive: `compilation_result`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # compilation result, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `compilation_result`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] release_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this release attempt. class ScheduledReleaseRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#disabled ⇒ ::Boolean
Returns Optional. Disables automatic creation of compilation results.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1230 class ReleaseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a compilation result for this release # config. # @!attribute [rw] compilation_result # @return [::String] # The name of the created compilation result, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/compilationResults/*`. # # Note: The following fields are mutually exclusive: `compilation_result`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # compilation result, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `compilation_result`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] release_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this release attempt. class ScheduledReleaseRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#git_commitish ⇒ ::String
Returns Required. Git commit/tag/branch name at which the repository should be compiled. Must exist in the remote repository. Examples:
- a commit SHA:
12ade345 - a tag:
tag1 - a branch name:
branch1.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1230 class ReleaseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a compilation result for this release # config. # @!attribute [rw] compilation_result # @return [::String] # The name of the created compilation result, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/compilationResults/*`. # # Note: The following fields are mutually exclusive: `compilation_result`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # compilation result, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `compilation_result`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] release_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this release attempt. class ScheduledReleaseRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#internal_metadata ⇒ ::String (readonly)
Returns Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1230 class ReleaseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a compilation result for this release # config. # @!attribute [rw] compilation_result # @return [::String] # The name of the created compilation result, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/compilationResults/*`. # # Note: The following fields are mutually exclusive: `compilation_result`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # compilation result, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `compilation_result`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] release_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this release attempt. class ScheduledReleaseRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The release config's name.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1230 class ReleaseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a compilation result for this release # config. # @!attribute [rw] compilation_result # @return [::String] # The name of the created compilation result, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/compilationResults/*`. # # Note: The following fields are mutually exclusive: `compilation_result`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # compilation result, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `compilation_result`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] release_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this release attempt. class ScheduledReleaseRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#recent_scheduled_release_records ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::ReleaseConfig::ScheduledReleaseRecord> (readonly)
Returns Output only. Records of the 10 most recent scheduled release attempts,
ordered in descending order of release_time. Updated whenever automatic
creation of a compilation result is triggered by cron_schedule.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1230 class ReleaseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a compilation result for this release # config. # @!attribute [rw] compilation_result # @return [::String] # The name of the created compilation result, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/compilationResults/*`. # # Note: The following fields are mutually exclusive: `compilation_result`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # compilation result, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `compilation_result`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] release_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this release attempt. class ScheduledReleaseRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#release_compilation_result ⇒ ::String
Returns Optional. The name of the currently released compilation result for this
release config. This value is updated when a compilation result is
automatically created from this release config (using cron_schedule), or
when this resource is updated by API call (perhaps to roll back to an
earlier release). The compilation result must have been created using this
release config. Must be in the format
projects/*/locations/*/repositories/*/compilationResults/*.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1230 class ReleaseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a compilation result for this release # config. # @!attribute [rw] compilation_result # @return [::String] # The name of the created compilation result, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/compilationResults/*`. # # Note: The following fields are mutually exclusive: `compilation_result`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # compilation result, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `compilation_result`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] release_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this release attempt. class ScheduledReleaseRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#time_zone ⇒ ::String
Returns Optional. Specifies the time zone to be used when interpreting cron_schedule. Must be a time zone name from the time zone database (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones). If left unspecified, the default is UTC.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1230 class ReleaseConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a compilation result for this release # config. # @!attribute [rw] compilation_result # @return [::String] # The name of the created compilation result, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/compilationResults/*`. # # Note: The following fields are mutually exclusive: `compilation_result`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # compilation result, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `compilation_result`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [r] release_time # @return [::Google::Protobuf::Timestamp] # Output only. The timestamp of this release attempt. class ScheduledReleaseRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |