Class: Google::Cloud::Dataform::V1beta1::TableUpdateTrigger

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents a table update trigger configuration.

Instance Attribute Summary collapse

Instance Attribute Details

#table::Google::Cloud::Dataform::V1beta1::Target

Returns The target table to trigger the workflow.

Returns:



1572
1573
1574
1575
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1572

class TableUpdateTrigger
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#trigger_update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The modification time of this table that resulted in an invocation of the workflow. This would be updated by the triggering service after a successful workflow invocation.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. The modification time of this table that resulted in an invocation of the workflow. This would be updated by the triggering service after a successful workflow invocation.



1572
1573
1574
1575
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1572

class TableUpdateTrigger
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end