Class: Google::Cloud::Dataform::V1beta1::TeamFolder
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::TeamFolder
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a Dataform TeamFolder. This is a resource that sits at the project level and is used to organize Repositories and Folders with hierarchical access controls. They provide a team context and stricter access controls.
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#creator_iam_principal ⇒ ::String
readonly
Output only.
-
#display_name ⇒ ::String
Required.
-
#internal_metadata ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of when the TeamFolder was created.
2945 2946 2947 2948 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2945 class TeamFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#creator_iam_principal ⇒ ::String (readonly)
Returns Output only. The IAM principal identifier of the creator of the TeamFolder.
2945 2946 2947 2948 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2945 class TeamFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. The TeamFolder's user-friendly name.
2945 2946 2947 2948 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2945 class TeamFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#internal_metadata ⇒ ::String (readonly)
Returns Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.
2945 2946 2947 2948 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2945 class TeamFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The TeamFolder's name.
2945 2946 2947 2948 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2945 class TeamFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of when the TeamFolder was last updated.
2945 2946 2947 2948 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2945 class TeamFolder include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |