Class: Google::Cloud::Dataform::V1beta1::UpdateFolderRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

UpdateFolder request message.

Instance Attribute Summary collapse

Instance Attribute Details

#folder::Google::Cloud::Dataform::V1beta1::Folder

Returns Required. The updated Folder.

Returns:



2773
2774
2775
2776
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2773

class UpdateFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Specifies the fields to be updated in the Folder. If left unset, all fields that can be updated, will be updated. A few fields cannot be updated and will be ignored if specified in the update_mask (e.g. parent_name, team_folder_name).

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Specifies the fields to be updated in the Folder. If left unset, all fields that can be updated, will be updated. A few fields cannot be updated and will be ignored if specified in the update_mask (e.g. parent_name, team_folder_name).



2773
2774
2775
2776
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2773

class UpdateFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end