Class: Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::NotebookAction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents a workflow action that will run against a Notebook runtime.

Instance Attribute Summary collapse

Instance Attribute Details

#contents::String (readonly)

Returns Output only. The code contents of a Notebook to be run.

Returns:

  • (::String)

    Output only. The code contents of a Notebook to be run.



2706
2707
2708
2709
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2706

class NotebookAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#file_path::String (readonly)

Returns Output only. The path to the notebook file in the repository.

Returns:

  • (::String)

    Output only. The path to the notebook file in the repository.



2706
2707
2708
2709
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2706

class NotebookAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#job_id::String (readonly)

Returns Output only. The ID of the Gemini Enterprise Agent Platform job that executed the notebook in contents and also the ID used for the outputs created in Google Cloud Storage buckets. Only set once the job has started to run.

Returns:

  • (::String)

    Output only. The ID of the Gemini Enterprise Agent Platform job that executed the notebook in contents and also the ID used for the outputs created in Google Cloud Storage buckets. Only set once the job has started to run.



2706
2707
2708
2709
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2706

class NotebookAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end