Module: Google::Cloud::Dataform::V1beta1::WorkflowTriggerConfig::Condition

Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

The condition to use when triggering the workflow.

Constant Summary collapse

CONDITION_UNSPECIFIED =

If CONDITION_UNSPECIFIED, the default value is ANY.

0
ALL =

If ALL, all the trigger config conditions must be met before a workflow is invoked.

1
ANY =

If ANY, at least one of the trigger config conditions must be met before a workflow is invoked.

2