Module: Google::Longrunning::Operations
- Defined in:
- lib/google/longrunning/operations.rb,
lib/google/longrunning/operations/rest.rb,
lib/google/longrunning/operations/client.rb,
lib/google/longrunning/operations/operations.rb,
lib/google/longrunning/operations/credentials.rb,
lib/google/longrunning/operations/rest/client.rb,
lib/google/longrunning/operations/rest/operations.rb,
lib/google/longrunning/operations/rest/service_stub.rb
Overview
Manages long-running operations with an API service.
When an API method normally takes long time to complete, it can be designed
to return Operation to the client, and the
client can use this interface to receive the real response asynchronously by
polling the operation resource, or pass the operation resource to another API
(such as Pub/Sub API) to receive the response. Any API service that returns
long-running operations should implement the Operations interface so
developers can have a consistent client experience.
To load this service and instantiate a REST client:
require "google/longrunning/operations/rest"
client = ::Google::Longrunning::Operations::Rest::Client.new
Defined Under Namespace
Modules: Rest Classes: Client, Credentials, Operations