Class: Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
CommitRepositoryChanges request message.
Defined Under Namespace
Classes: FileOperation, FileOperationsEntry
Instance Attribute Summary collapse
-
#commit_metadata ⇒ ::Google::Cloud::Dataform::V1beta1::CommitMetadata
Required.
-
#file_operations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation}
Optional.
-
#name ⇒ ::String
Required.
-
#required_head_commit_sha ⇒ ::String
Optional.
Instance Attribute Details
#commit_metadata ⇒ ::Google::Cloud::Dataform::V1beta1::CommitMetadata
Returns Required. The changes to commit to the repository.
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 374 class CommitRepositoryChangesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single file operation to the repository. # @!attribute [rw] write_file # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation::WriteFile] # Represents the write operation. # # Note: The following fields are mutually exclusive: `write_file`, `delete_file`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] delete_file # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation::DeleteFile] # Represents the delete operation. # # Note: The following fields are mutually exclusive: `delete_file`, `write_file`. If a field in that set is populated, all other fields in the set will automatically be cleared. class FileOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the write file operation (for files added or modified). # @!attribute [rw] contents # @return [::String] # The file's contents. class WriteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the delete file operation. class DeleteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation] class FileOperationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#file_operations ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation}
Returns Optional. A map to the path of the file to the operation. The path is the full file path including filename, from repository root.
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 374 class CommitRepositoryChangesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single file operation to the repository. # @!attribute [rw] write_file # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation::WriteFile] # Represents the write operation. # # Note: The following fields are mutually exclusive: `write_file`, `delete_file`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] delete_file # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation::DeleteFile] # Represents the delete operation. # # Note: The following fields are mutually exclusive: `delete_file`, `write_file`. If a field in that set is populated, all other fields in the set will automatically be cleared. class FileOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the write file operation (for files added or modified). # @!attribute [rw] contents # @return [::String] # The file's contents. class WriteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the delete file operation. class DeleteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation] class FileOperationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The repository's name.
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 374 class CommitRepositoryChangesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single file operation to the repository. # @!attribute [rw] write_file # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation::WriteFile] # Represents the write operation. # # Note: The following fields are mutually exclusive: `write_file`, `delete_file`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] delete_file # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation::DeleteFile] # Represents the delete operation. # # Note: The following fields are mutually exclusive: `delete_file`, `write_file`. If a field in that set is populated, all other fields in the set will automatically be cleared. class FileOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the write file operation (for files added or modified). # @!attribute [rw] contents # @return [::String] # The file's contents. class WriteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the delete file operation. class DeleteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation] class FileOperationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#required_head_commit_sha ⇒ ::String
Returns Optional. The commit SHA which must be the repository's current HEAD before applying this commit; otherwise this request will fail. If unset, no validation on the current HEAD commit SHA is performed.
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 374 class CommitRepositoryChangesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single file operation to the repository. # @!attribute [rw] write_file # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation::WriteFile] # Represents the write operation. # # Note: The following fields are mutually exclusive: `write_file`, `delete_file`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] delete_file # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation::DeleteFile] # Represents the delete operation. # # Note: The following fields are mutually exclusive: `delete_file`, `write_file`. If a field in that set is populated, all other fields in the set will automatically be cleared. class FileOperation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the write file operation (for files added or modified). # @!attribute [rw] contents # @return [::String] # The file's contents. class WriteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the delete file operation. class DeleteFile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Dataform::V1beta1::CommitRepositoryChangesRequest::FileOperation] class FileOperationsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |