Class: Google::Cloud::Dataform::V1beta1::CompilationResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents the result of compiling a Dataform project.

Defined Under Namespace

Classes: CompilationError

Instance Attribute Summary collapse

Instance Attribute Details

#code_compilation_config::Google::Cloud::Dataform::V1beta1::CodeCompilationConfig

Returns Immutable. If set, fields of code_compilation_config override the default compilation settings that are specified in dataform.json.

Returns:



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#compilation_errors::Array<::Google::Cloud::Dataform::V1beta1::CompilationResult::CompilationError> (readonly)

Returns Output only. Errors encountered during project compilation.

Returns:



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The timestamp of when the compilation result was created.

Returns:



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#data_encryption_state::Google::Cloud::Dataform::V1beta1::DataEncryptionState (readonly)

Returns Output only. Only set if the repository has a KMS Key.

Returns:



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#dataform_core_version::String (readonly)

Returns Output only. The version of @dataform/core that was used for compilation.

Returns:

  • (::String)

    Output only. The version of @dataform/core that was used for compilation.



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#git_commitish::String

Returns Immutable. Git commit/tag/branch name at which the repository should be compiled. Must exist in the remote repository. Examples:

  • a commit SHA: 12ade345
  • a tag: tag1
  • a branch name: branch1

Note: The following fields are mutually exclusive: git_commitish, workspace, release_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Immutable. Git commit/tag/branch name at which the repository should be compiled. Must exist in the remote repository. Examples:

    • a commit SHA: 12ade345
    • a tag: tag1
    • a branch name: branch1

    Note: The following fields are mutually exclusive: git_commitish, workspace, release_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#internal_metadata::String (readonly)

Returns Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.

Returns:

  • (::String)

    Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string.



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String (readonly)

Returns Output only. The compilation result's name.

Returns:

  • (::String)

    Output only. The compilation result's name.



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#private_resource_metadata::Google::Cloud::Dataform::V1beta1::PrivateResourceMetadata (readonly)

Returns Output only. Metadata indicating whether this resource is user-scoped. CompilationResult resource is user_scoped only if it is sourced from a workspace.

Returns:



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#release_config::String

Returns Immutable. The name of the release config to compile. Must be in the format projects/*/locations/*/repositories/*/releaseConfigs/*.

Note: The following fields are mutually exclusive: release_config, git_commitish, workspace. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Immutable. The name of the release config to compile. Must be in the format projects/*/locations/*/repositories/*/releaseConfigs/*.

    Note: The following fields are mutually exclusive: release_config, git_commitish, workspace. If a field in that set is populated, all other fields in the set will automatically be cleared.



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#resolved_git_commit_sha::String (readonly)

Returns Output only. The fully resolved Git commit SHA of the code that was compiled. Not set for compilation results whose source is a workspace.

Returns:

  • (::String)

    Output only. The fully resolved Git commit SHA of the code that was compiled. Not set for compilation results whose source is a workspace.



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#workspace::String

Returns Immutable. The name of the workspace to compile. Must be in the format projects/*/locations/*/repositories/*/workspaces/*.

Note: The following fields are mutually exclusive: workspace, git_commitish, release_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Immutable. The name of the workspace to compile. Must be in the format projects/*/locations/*/repositories/*/workspaces/*.

    Note: The following fields are mutually exclusive: workspace, git_commitish, release_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1400

class CompilationResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An error encountered when attempting to compile a Dataform project.
  # @!attribute [r] message
  #   @return [::String]
  #     Output only. The error's top level message.
  # @!attribute [r] stack
  #   @return [::String]
  #     Output only. The error's full stack trace.
  # @!attribute [r] path
  #   @return [::String]
  #     Output only. The path of the file where this error occurred, if
  #     available, relative to the project root.
  # @!attribute [r] action_target
  #   @return [::Google::Cloud::Dataform::V1beta1::Target]
  #     Output only. The identifier of the action where this error occurred, if
  #     available.
  class CompilationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end