Class: Google::Cloud::Dataform::V1beta1::CompilationResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::CompilationResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents the result of compiling a Dataform project.
Defined Under Namespace
Classes: CompilationError
Instance Attribute Summary collapse
-
#code_compilation_config ⇒ ::Google::Cloud::Dataform::V1beta1::CodeCompilationConfig
Immutable.
-
#compilation_errors ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::CompilationResult::CompilationError>
readonly
Output only.
-
#dataform_core_version ⇒ ::String
readonly
Output only.
-
#git_commitish ⇒ ::String
Immutable.
-
#name ⇒ ::String
readonly
Output only.
-
#release_config ⇒ ::String
Immutable.
-
#resolved_git_commit_sha ⇒ ::String
readonly
Output only.
-
#workspace ⇒ ::String
Immutable.
Instance Attribute Details
#code_compilation_config ⇒ ::Google::Cloud::Dataform::V1beta1::CodeCompilationConfig
Returns Immutable. If set, fields of code_compilation_config override the default
compilation settings that are specified in dataform.json.
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1159 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if # available, relative to the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if # available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#compilation_errors ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::CompilationResult::CompilationError> (readonly)
Returns Output only. Errors encountered during project compilation.
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1159 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if # available, relative to the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if # available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#dataform_core_version ⇒ ::String (readonly)
Returns Output only. The version of @dataform/core that was used for compilation.
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1159 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if # available, relative to the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if # available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#git_commitish ⇒ ::String
Returns Immutable. Git commit/tag/branch name at which the repository should be compiled. Must exist in the remote repository. Examples:
- a commit SHA:
12ade345 - a tag:
tag1 - a branch name:
branch1
Note: The following fields are mutually exclusive: git_commitish, workspace, release_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1159 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if # available, relative to the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if # available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String (readonly)
Returns Output only. The compilation result's name.
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1159 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if # available, relative to the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if # available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#release_config ⇒ ::String
Returns Immutable. The name of the release config to compile. The release
config's 'current_compilation_result' field will be updated to this
compilation result. Must be in the format
projects/*/locations/*/repositories/*/releaseConfigs/*.
Note: The following fields are mutually exclusive: release_config, git_commitish, workspace. If a field in that set is populated, all other fields in the set will automatically be cleared.
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1159 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if # available, relative to the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if # available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#resolved_git_commit_sha ⇒ ::String (readonly)
Returns Output only. The fully resolved Git commit SHA of the code that was compiled. Not set for compilation results whose source is a workspace.
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1159 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if # available, relative to the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if # available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#workspace ⇒ ::String
Returns Immutable. The name of the workspace to compile. Must be in the format
projects/*/locations/*/repositories/*/workspaces/*.
Note: The following fields are mutually exclusive: workspace, git_commitish, release_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1159 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if # available, relative to the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if # available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |