Class: Google::Cloud::Dataform::V1beta1::CompilationResult
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::CompilationResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents the result of compiling a Dataform project.
Defined Under Namespace
Classes: CodeCompilationConfig, CompilationError
Instance Attribute Summary collapse
-
#code_compilation_config ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResult::CodeCompilationConfig
Immutable.
-
#compilation_errors ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::CompilationResult::CompilationError>
readonly
Output only.
-
#dataform_core_version ⇒ ::String
readonly
Output only.
-
#git_commitish ⇒ ::String
Immutable.
-
#name ⇒ ::String
readonly
Output only.
-
#workspace ⇒ ::String
Immutable.
Instance Attribute Details
#code_compilation_config ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResult::CodeCompilationConfig
Returns Immutable. If set, fields of code_compilation_overrides override the default
compilation settings that are specified in dataform.json.
674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 674 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures various aspects of Dataform code compilation. # @!attribute [rw] default_database # @return [::String] # Optional. The default database (Google Cloud project ID). # @!attribute [rw] default_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID). # @!attribute [rw] default_location # @return [::String] # Optional. The default BigQuery location to use. Defaults to "US". # See the BigQuery docs for a full list of locations: # https://cloud.google.com/bigquery/docs/locations. # @!attribute [rw] assertion_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID) for assertions. # @!attribute [rw] vars # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-defined variables that are made available to project code during # compilation. # @!attribute [rw] database_suffix # @return [::String] # Optional. The suffix that should be appended to all database (Google Cloud project # ID) names. # @!attribute [rw] schema_suffix # @return [::String] # Optional. The suffix that should be appended to all schema (BigQuery dataset ID) # names. # @!attribute [rw] table_prefix # @return [::String] # Optional. The prefix that should be prepended to all table names. class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if available, relative to # the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#compilation_errors ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::CompilationResult::CompilationError> (readonly)
Returns Output only. Errors encountered during project compilation.
674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 674 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures various aspects of Dataform code compilation. # @!attribute [rw] default_database # @return [::String] # Optional. The default database (Google Cloud project ID). # @!attribute [rw] default_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID). # @!attribute [rw] default_location # @return [::String] # Optional. The default BigQuery location to use. Defaults to "US". # See the BigQuery docs for a full list of locations: # https://cloud.google.com/bigquery/docs/locations. # @!attribute [rw] assertion_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID) for assertions. # @!attribute [rw] vars # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-defined variables that are made available to project code during # compilation. # @!attribute [rw] database_suffix # @return [::String] # Optional. The suffix that should be appended to all database (Google Cloud project # ID) names. # @!attribute [rw] schema_suffix # @return [::String] # Optional. The suffix that should be appended to all schema (BigQuery dataset ID) # names. # @!attribute [rw] table_prefix # @return [::String] # Optional. The prefix that should be prepended to all table names. class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if available, relative to # the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#dataform_core_version ⇒ ::String (readonly)
Returns Output only. The version of @dataform/core that was used for compilation.
674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 674 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures various aspects of Dataform code compilation. # @!attribute [rw] default_database # @return [::String] # Optional. The default database (Google Cloud project ID). # @!attribute [rw] default_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID). # @!attribute [rw] default_location # @return [::String] # Optional. The default BigQuery location to use. Defaults to "US". # See the BigQuery docs for a full list of locations: # https://cloud.google.com/bigquery/docs/locations. # @!attribute [rw] assertion_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID) for assertions. # @!attribute [rw] vars # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-defined variables that are made available to project code during # compilation. # @!attribute [rw] database_suffix # @return [::String] # Optional. The suffix that should be appended to all database (Google Cloud project # ID) names. # @!attribute [rw] schema_suffix # @return [::String] # Optional. The suffix that should be appended to all schema (BigQuery dataset ID) # names. # @!attribute [rw] table_prefix # @return [::String] # Optional. The prefix that should be prepended to all table names. class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if available, relative to # the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#git_commitish ⇒ ::String
Returns Immutable. Git commit/tag/branch name at which the repository should be compiled. Must exist in the remote repository. Examples:
- a commit SHA:
12ade345 - a tag:
tag1 - a branch name:
branch1.
674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 674 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures various aspects of Dataform code compilation. # @!attribute [rw] default_database # @return [::String] # Optional. The default database (Google Cloud project ID). # @!attribute [rw] default_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID). # @!attribute [rw] default_location # @return [::String] # Optional. The default BigQuery location to use. Defaults to "US". # See the BigQuery docs for a full list of locations: # https://cloud.google.com/bigquery/docs/locations. # @!attribute [rw] assertion_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID) for assertions. # @!attribute [rw] vars # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-defined variables that are made available to project code during # compilation. # @!attribute [rw] database_suffix # @return [::String] # Optional. The suffix that should be appended to all database (Google Cloud project # ID) names. # @!attribute [rw] schema_suffix # @return [::String] # Optional. The suffix that should be appended to all schema (BigQuery dataset ID) # names. # @!attribute [rw] table_prefix # @return [::String] # Optional. The prefix that should be prepended to all table names. class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if available, relative to # the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String (readonly)
Returns Output only. The compilation result's name.
674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 674 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures various aspects of Dataform code compilation. # @!attribute [rw] default_database # @return [::String] # Optional. The default database (Google Cloud project ID). # @!attribute [rw] default_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID). # @!attribute [rw] default_location # @return [::String] # Optional. The default BigQuery location to use. Defaults to "US". # See the BigQuery docs for a full list of locations: # https://cloud.google.com/bigquery/docs/locations. # @!attribute [rw] assertion_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID) for assertions. # @!attribute [rw] vars # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-defined variables that are made available to project code during # compilation. # @!attribute [rw] database_suffix # @return [::String] # Optional. The suffix that should be appended to all database (Google Cloud project # ID) names. # @!attribute [rw] schema_suffix # @return [::String] # Optional. The suffix that should be appended to all schema (BigQuery dataset ID) # names. # @!attribute [rw] table_prefix # @return [::String] # Optional. The prefix that should be prepended to all table names. class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if available, relative to # the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#workspace ⇒ ::String
Returns Immutable. The name of the workspace to compile. Must be in the format
projects/*/locations/*/repositories/*/workspaces/*.
674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 674 class CompilationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configures various aspects of Dataform code compilation. # @!attribute [rw] default_database # @return [::String] # Optional. The default database (Google Cloud project ID). # @!attribute [rw] default_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID). # @!attribute [rw] default_location # @return [::String] # Optional. The default BigQuery location to use. Defaults to "US". # See the BigQuery docs for a full list of locations: # https://cloud.google.com/bigquery/docs/locations. # @!attribute [rw] assertion_schema # @return [::String] # Optional. The default schema (BigQuery dataset ID) for assertions. # @!attribute [rw] vars # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. User-defined variables that are made available to project code during # compilation. # @!attribute [rw] database_suffix # @return [::String] # Optional. The suffix that should be appended to all database (Google Cloud project # ID) names. # @!attribute [rw] schema_suffix # @return [::String] # Optional. The suffix that should be appended to all schema (BigQuery dataset ID) # names. # @!attribute [rw] table_prefix # @return [::String] # Optional. The prefix that should be prepended to all table names. class CodeCompilationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class VarsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # An error encountered when attempting to compile a Dataform project. # @!attribute [r] message # @return [::String] # Output only. The error's top level message. # @!attribute [r] stack # @return [::String] # Output only. The error's full stack trace. # @!attribute [r] path # @return [::String] # Output only. The path of the file where this error occurred, if available, relative to # the project root. # @!attribute [r] action_target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Output only. The identifier of the action where this error occurred, if available. class CompilationError include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |