Class: Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a database relation.
Defined Under Namespace
Modules: FileFormat, RelationType, TableFormat Classes: AdditionalOptionsEntry, IncrementalTableConfig
Instance Attribute Summary collapse
-
#additional_options ⇒ ::Google::Protobuf::Map{::String => ::String}
Additional options that will be provided as key/value pairs into the options clause of a create table/view statement.
-
#cluster_expressions ⇒ ::Array<::String>
A list of columns or SQL expressions used to cluster the table.
-
#connection ⇒ ::String
Optional.
-
#dependency_targets ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::Target>
A list of actions that this action depends on.
-
#disabled ⇒ ::Boolean
Whether this action is disabled (i.e. should not be run).
-
#file_format ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::FileFormat
Optional.
-
#incremental_table_config ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig
Configures
INCREMENTAL_TABLEsettings for this relation. -
#partition_expiration_days ⇒ ::Integer
Sets the partition expiration in days.
-
#partition_expression ⇒ ::String
The SQL expression used to partition the relation.
-
#post_operations ⇒ ::Array<::String>
SQL statements to be executed after creating the relation.
-
#pre_operations ⇒ ::Array<::String>
SQL statements to be executed before creating the relation.
-
#relation_descriptor ⇒ ::Google::Cloud::Dataform::V1beta1::RelationDescriptor
Descriptor for the relation and its columns.
-
#relation_type ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType
The type of this relation.
-
#require_partition_filter ⇒ ::Boolean
Specifies whether queries on this table must include a predicate filter that filters on the partitioning column.
-
#select_query ⇒ ::String
The SELECT query which returns rows which this relation should contain.
-
#storage_uri ⇒ ::String
Optional.
-
#table_format ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::TableFormat
Optional.
-
#tags ⇒ ::Array<::String>
Arbitrary, user-defined tags on this action.
Instance Attribute Details
#additional_options ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Additional options that will be provided as key/value pairs into the options clause of a create table/view statement. See https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language for more information on which options are supported.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#cluster_expressions ⇒ ::Array<::String>
Returns A list of columns or SQL expressions used to cluster the table.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#connection ⇒ ::String
Returns Optional. The connection specifying the credentials to be used to read
and write to external storage, such as Cloud Storage. The connection can
have the form {project}.{location}.{connection_id} or
projects/{project}/locations/{location}/connections/{connection_id},
or be set to DEFAULT.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#dependency_targets ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::Target>
Returns A list of actions that this action depends on.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#disabled ⇒ ::Boolean
Returns Whether this action is disabled (i.e. should not be run).
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#file_format ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::FileFormat
Returns Optional. The file format for the BigQuery table.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#incremental_table_config ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig
Returns Configures INCREMENTAL_TABLE settings for this relation. Only set if
relation_type is INCREMENTAL_TABLE.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#partition_expiration_days ⇒ ::Integer
Returns Sets the partition expiration in days.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#partition_expression ⇒ ::String
Returns The SQL expression used to partition the relation.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#post_operations ⇒ ::Array<::String>
Returns SQL statements to be executed after creating the relation.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#pre_operations ⇒ ::Array<::String>
Returns SQL statements to be executed before creating the relation.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#relation_descriptor ⇒ ::Google::Cloud::Dataform::V1beta1::RelationDescriptor
Returns Descriptor for the relation and its columns.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#relation_type ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType
Returns The type of this relation.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#require_partition_filter ⇒ ::Boolean
Returns Specifies whether queries on this table must include a predicate filter that filters on the partitioning column.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#select_query ⇒ ::String
Returns The SELECT query which returns rows which this relation should contain.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#storage_uri ⇒ ::String
Returns Optional. The fully qualified location prefix of the external folder
where table data is stored. The URI should be in the format
gs://bucket/path_to_table/.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#table_format ⇒ ::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::TableFormat
Returns Optional. The table format for the BigQuery table.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |
#tags ⇒ ::Array<::String>
Returns Arbitrary, user-defined tags on this action.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1733 class Relation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Contains settings for relations of type `INCREMENTAL_TABLE`. # @!attribute [rw] incremental_select_query # @return [::String] # The SELECT query which returns rows which should be inserted into the # relation if it already exists and is not being refreshed. # @!attribute [rw] refresh_disabled # @return [::Boolean] # Whether this table should be protected from being refreshed. # @!attribute [rw] unique_key_parts # @return [::Array<::String>] # A set of columns or SQL expressions used to define row uniqueness. # If any duplicates are discovered (as defined by `unique_key_parts`), # only the newly selected rows (as defined by `incremental_select_query`) # will be included in the relation. # @!attribute [rw] update_partition_filter # @return [::String] # A SQL expression conditional used to limit the set of existing rows # considered for a merge operation (see `unique_key_parts` for more # information). # @!attribute [rw] incremental_pre_operations # @return [::Array<::String>] # SQL statements to be executed before inserting new rows into the # relation. # @!attribute [rw] incremental_post_operations # @return [::Array<::String>] # SQL statements to be executed after inserting new rows into the # relation. class IncrementalTableConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class AdditionalOptionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Indicates the type of this relation. module RelationType # Default value. This value is unused. RELATION_TYPE_UNSPECIFIED = 0 # The relation is a table. TABLE = 1 # The relation is a view. VIEW = 2 # The relation is an incrementalized table. INCREMENTAL_TABLE = 3 # The relation is a materialized view. MATERIALIZED_VIEW = 4 end # Supported table formats for BigQuery tables. module TableFormat # Default value. TABLE_FORMAT_UNSPECIFIED = 0 # Apache Iceberg format. ICEBERG = 1 end # Supported file formats for BigQuery tables. module FileFormat # Default value. FILE_FORMAT_UNSPECIFIED = 0 # Apache Parquet format. PARQUET = 1 end end |