Class: Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents a database relation.

Defined Under Namespace

Modules: RelationType Classes: AdditionalOptionsEntry, IncrementalTableConfig

Instance Attribute Summary collapse

Instance Attribute Details

#additional_options::Google::Protobuf::Map{::String => ::String}

Returns Additional options that will be provided as key/value pairs into the options clause of a create table/view statement. See https://cloud.google.com/bigquery/docs/reference/standard-sql/data-definition-language for more information on which options are supported.

Returns:



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#cluster_expressions::Array<::String>

Returns A list of columns or SQL expressions used to cluster the table.

Returns:

  • (::Array<::String>)

    A list of columns or SQL expressions used to cluster the table.



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#dependency_targets::Array<::Google::Cloud::Dataform::V1beta1::Target>

Returns A list of actions that this action depends on.

Returns:



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#disabled::Boolean

Returns Whether this action is disabled (i.e. should not be run).

Returns:

  • (::Boolean)

    Whether this action is disabled (i.e. should not be run).



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#incremental_table_config::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::IncrementalTableConfig

Returns Configures INCREMENTAL_TABLE settings for this relation. Only set if relation_type is INCREMENTAL_TABLE.

Returns:



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#partition_expiration_days::Integer

Returns Sets the partition expiration in days.

Returns:

  • (::Integer)

    Sets the partition expiration in days.



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#partition_expression::String

Returns The SQL expression used to partition the relation.

Returns:

  • (::String)

    The SQL expression used to partition the relation.



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#post_operations::Array<::String>

Returns SQL statements to be executed after creating the relation.

Returns:

  • (::Array<::String>)

    SQL statements to be executed after creating the relation.



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#pre_operations::Array<::String>

Returns SQL statements to be executed before creating the relation.

Returns:

  • (::Array<::String>)

    SQL statements to be executed before creating the relation.



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#relation_descriptor::Google::Cloud::Dataform::V1beta1::RelationDescriptor

Returns Descriptor for the relation and its columns.

Returns:



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#relation_type::Google::Cloud::Dataform::V1beta1::CompilationResultAction::Relation::RelationType

Returns The type of this relation.



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#require_partition_filter::Boolean

Returns Specifies whether queries on this table must include a predicate filter that filters on the partitioning column.

Returns:

  • (::Boolean)

    Specifies whether queries on this table must include a predicate filter that filters on the partitioning column.



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#select_query::String

Returns The SELECT query which returns rows which this relation should contain.

Returns:

  • (::String)

    The SELECT query which returns rows which this relation should contain.



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end

#tags::Array<::String>

Returns Arbitrary, user-defined tags on this action.

Returns:

  • (::Array<::String>)

    Arbitrary, user-defined tags on this action.



934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 934

class Relation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Contains settings for relations of type `INCREMENTAL_TABLE`.
  # @!attribute [rw] incremental_select_query
  #   @return [::String]
  #     The SELECT query which returns rows which should be inserted into the
  #     relation if it already exists and is not being refreshed.
  # @!attribute [rw] refresh_disabled
  #   @return [::Boolean]
  #     Whether this table should be protected from being refreshed.
  # @!attribute [rw] unique_key_parts
  #   @return [::Array<::String>]
  #     A set of columns or SQL expressions used to define row uniqueness.
  #     If any duplicates are discovered (as defined by `unique_key_parts`),
  #     only the newly selected rows (as defined by `incremental_select_query`)
  #     will be included in the relation.
  # @!attribute [rw] update_partition_filter
  #   @return [::String]
  #     A SQL expression conditional used to limit the set of existing rows
  #     considered for a merge operation (see `unique_key_parts` for more
  #     information).
  # @!attribute [rw] incremental_pre_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed before inserting new rows into the
  #     relation.
  # @!attribute [rw] incremental_post_operations
  #   @return [::Array<::String>]
  #     SQL statements to be executed after inserting new rows into the
  #     relation.
  class IncrementalTableConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AdditionalOptionsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Indicates the type of this relation.
  module RelationType
    # Default value. This value is unused.
    RELATION_TYPE_UNSPECIFIED = 0

    # The relation is a table.
    TABLE = 1

    # The relation is a view.
    VIEW = 2

    # The relation is an incrementalized table.
    INCREMENTAL_TABLE = 3

    # The relation is a materialized view.
    MATERIALIZED_VIEW = 4
  end
end