Class: Google::Cloud::Dataform::V1beta1::ComputeRepositoryAccessTokenStatusResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

ComputeRepositoryAccessTokenStatus response message.

Defined Under Namespace

Modules: TokenStatus

Instance Attribute Summary collapse

Instance Attribute Details

#token_status::Google::Cloud::Dataform::V1beta1::ComputeRepositoryAccessTokenStatusResponse::TokenStatus

Returns Indicates the status of the Git access token.

Returns:



540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 540

class ComputeRepositoryAccessTokenStatusResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates the status of a Git authentication token.
  module TokenStatus
    # Default value. This value is unused.
    TOKEN_STATUS_UNSPECIFIED = 0

    # The token could not be found in Secret Manager (or the Dataform
    # Service Account did not have permission to access it).
    NOT_FOUND = 1

    # The token could not be used to authenticate against the Git remote.
    INVALID = 2

    # The token was used successfully to authenticate against the Git remote.
    VALID = 3
  end
end