Class: Google::Cloud::Dataform::V1beta1::CreateFolderRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

CreateFolder request message.

Instance Attribute Summary collapse

Instance Attribute Details

#folder::Google::Cloud::Dataform::V1beta1::Folder

Returns Required. The Folder to create.

Returns:



2735
2736
2737
2738
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2735

class CreateFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#folder_id::String

Returns The ID to use for the Folder, which will become the final component of the Folder's resource name.

Returns:

  • (::String)

    The ID to use for the Folder, which will become the final component of the Folder's resource name.



2735
2736
2737
2738
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2735

class CreateFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The location in which to create the Folder. Must be in the format projects/*/locations/*.

Returns:

  • (::String)

    Required. The location in which to create the Folder. Must be in the format projects/*/locations/*.



2735
2736
2737
2738
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2735

class CreateFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end