Class: Google::Cloud::Dataform::V1beta1::CreateTeamFolderRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::CreateTeamFolderRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
CreateTeamFolder request message.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#team_folder ⇒ ::Google::Cloud::Dataform::V1beta1::TeamFolder
Required.
-
#team_folder_id ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The location in which to create the TeamFolder. Must be in the
format projects/*/locations/*.
3116 3117 3118 3119 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3116 class CreateTeamFolderRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#team_folder ⇒ ::Google::Cloud::Dataform::V1beta1::TeamFolder
Returns Required. The TeamFolder to create.
3116 3117 3118 3119 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3116 class CreateTeamFolderRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#team_folder_id ⇒ ::String
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Deprecated: This field is not used. The resource name is generated automatically. The ID to use for the TeamFolder, which will become the final component of the TeamFolder's resource name.
3116 3117 3118 3119 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3116 class CreateTeamFolderRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |