Class: Google::Cloud::Dataform::V1beta1::CreateTeamFolderRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

CreateTeamFolder request message.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The location in which to create the TeamFolder. Must be in the format projects/*/locations/*.

Returns:

  • (::String)

    Required. The location in which to create the TeamFolder. Must be in the format projects/*/locations/*.



2962
2963
2964
2965
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2962

class CreateTeamFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#team_folder::Google::Cloud::Dataform::V1beta1::TeamFolder

Returns Required. The TeamFolder to create.

Returns:



2962
2963
2964
2965
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2962

class CreateTeamFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#team_folder_id::String

Returns The ID to use for the TeamFolder, which will become the final component of the TeamFolder's resource name.

Returns:

  • (::String)

    The ID to use for the TeamFolder, which will become the final component of the TeamFolder's resource name.



2962
2963
2964
2965
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2962

class CreateTeamFolderRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end