Class: Google::Cloud::Dataform::V1beta1::DeleteRepositoryLongRunningMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::DeleteRepositoryLongRunningMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents metadata about the progress of the DeleteRepository long-running operation.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#child_resources_count ⇒ ::Integer
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#percent_complete ⇒ ::Integer
readonly
Output only.
-
#remaining_child_resources_count ⇒ ::Integer
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Dataform::V1beta1::DeleteRepositoryLongRunningMetadata::State
readonly
Output only.
-
#target ⇒ ::String
readonly
Output only.
Instance Attribute Details
#child_resources_count ⇒ ::Integer (readonly)
Returns Output only. The total number of child resources (Compilation Results, Workflow Executions) that will be deleted.
3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3555 class DeleteRepositoryLongRunningMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteRepositoryLongRunning operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation is running. RUNNING = 1 # The operation has completed successfully. SUCCEEDED = 2 # The operation has failed. FAILED = 3 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation was created.
3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3555 class DeleteRepositoryLongRunningMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteRepositoryLongRunning operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation is running. RUNNING = 1 # The operation has completed successfully. SUCCEEDED = 2 # The operation has failed. FAILED = 3 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation finished running.
3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3555 class DeleteRepositoryLongRunningMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteRepositoryLongRunning operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation is running. RUNNING = 1 # The operation has completed successfully. SUCCEEDED = 2 # The operation has failed. FAILED = 3 end end |
#percent_complete ⇒ ::Integer (readonly)
Returns Output only. Percent complete of the operation [0, 100].
3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3555 class DeleteRepositoryLongRunningMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteRepositoryLongRunning operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation is running. RUNNING = 1 # The operation has completed successfully. SUCCEEDED = 2 # The operation has failed. FAILED = 3 end end |
#remaining_child_resources_count ⇒ ::Integer (readonly)
Returns Output only. The remaining number of child resources to be deleted.
3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3555 class DeleteRepositoryLongRunningMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteRepositoryLongRunning operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation is running. RUNNING = 1 # The operation has completed successfully. SUCCEEDED = 2 # The operation has failed. FAILED = 3 end end |
#state ⇒ ::Google::Cloud::Dataform::V1beta1::DeleteRepositoryLongRunningMetadata::State (readonly)
Returns Output only. The state of the operation.
3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3555 class DeleteRepositoryLongRunningMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteRepositoryLongRunning operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation is running. RUNNING = 1 # The operation has completed successfully. SUCCEEDED = 2 # The operation has failed. FAILED = 3 end end |
#target ⇒ ::String (readonly)
Returns Output only. Server-defined resource path for the target of the operation. Format: projects/{project}/locations/{location}/repositories/{repository}.
3555 3556 3557 3558 3559 3560 3561 3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3555 class DeleteRepositoryLongRunningMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the DeleteRepositoryLongRunning operation. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The operation is running. RUNNING = 1 # The operation has completed successfully. SUCCEEDED = 2 # The operation has failed. FAILED = 3 end end |