Class: Google::Cloud::Dataform::V1beta1::DeleteRepositoryLongRunningMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents metadata about the progress of the DeleteRepository long-running operation.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#child_resources_count::Integer (readonly)

Returns Output only. The total number of child resources (Compilation Results, Workflow Executions) that will be deleted.

Returns:

  • (::Integer)

    Output only. The total number of child resources (Compilation Results, Workflow Executions) that will be deleted.



3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3388

class DeleteRepositoryLongRunningMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the DeleteRepositoryLongRunning operation.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The operation is running.
    RUNNING = 1

    # The operation has completed successfully.
    SUCCEEDED = 2

    # The operation has failed.
    FAILED = 3
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation was created.

Returns:



3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3388

class DeleteRepositoryLongRunningMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the DeleteRepositoryLongRunning operation.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The operation is running.
    RUNNING = 1

    # The operation has completed successfully.
    SUCCEEDED = 2

    # The operation has failed.
    FAILED = 3
  end
end

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time the operation finished running.

Returns:



3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3388

class DeleteRepositoryLongRunningMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the DeleteRepositoryLongRunning operation.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The operation is running.
    RUNNING = 1

    # The operation has completed successfully.
    SUCCEEDED = 2

    # The operation has failed.
    FAILED = 3
  end
end

#percent_complete::Integer (readonly)

Returns Output only. Percent complete of the operation [0, 100].

Returns:

  • (::Integer)

    Output only. Percent complete of the operation [0, 100].



3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3388

class DeleteRepositoryLongRunningMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the DeleteRepositoryLongRunning operation.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The operation is running.
    RUNNING = 1

    # The operation has completed successfully.
    SUCCEEDED = 2

    # The operation has failed.
    FAILED = 3
  end
end

#remaining_child_resources_count::Integer (readonly)

Returns Output only. The remaining number of child resources to be deleted.

Returns:

  • (::Integer)

    Output only. The remaining number of child resources to be deleted.



3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3388

class DeleteRepositoryLongRunningMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the DeleteRepositoryLongRunning operation.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The operation is running.
    RUNNING = 1

    # The operation has completed successfully.
    SUCCEEDED = 2

    # The operation has failed.
    FAILED = 3
  end
end

#state::Google::Cloud::Dataform::V1beta1::DeleteRepositoryLongRunningMetadata::State (readonly)

Returns Output only. The state of the operation.

Returns:



3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3388

class DeleteRepositoryLongRunningMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the DeleteRepositoryLongRunning operation.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The operation is running.
    RUNNING = 1

    # The operation has completed successfully.
    SUCCEEDED = 2

    # The operation has failed.
    FAILED = 3
  end
end

#target::String (readonly)

Returns Output only. Server-defined resource path for the target of the operation. Format: projects/{project}/locations/{location}/repositories/{repository}.

Returns:

  • (::String)

    Output only. Server-defined resource path for the target of the operation. Format: projects/{project}/locations/{location}/repositories/{repository}



3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
3404
3405
3406
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3388

class DeleteRepositoryLongRunningMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Different states of the DeleteRepositoryLongRunning operation.
  module State
    # The state is unspecified.
    STATE_UNSPECIFIED = 0

    # The operation is running.
    RUNNING = 1

    # The operation has completed successfully.
    SUCCEEDED = 2

    # The operation has failed.
    FAILED = 3
  end
end