Class: Google::Cloud::Dataform::V1beta1::DeleteRepositoryRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::DeleteRepositoryRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
DeleteRepository request message.
Instance Attribute Summary collapse
-
#force ⇒ ::Boolean
If set to true, any child resources of this repository will also be deleted.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#force ⇒ ::Boolean
Returns If set to true, any child resources of this repository will also be deleted. (Otherwise, the request will only succeed if the repository has no child resources.).
245 246 247 248 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 245 class DeleteRepositoryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The repository's name.
245 246 247 248 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 245 class DeleteRepositoryRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |