Class: Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
FetchFileGitStatuses response message.
Defined Under Namespace
Classes: UncommittedFileChange
Instance Attribute Summary collapse
-
#uncommitted_file_changes ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange>
A list of all files which have uncommitted Git changes.
Instance Attribute Details
#uncommitted_file_changes ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange>
Returns A list of all files which have uncommitted Git changes. There will only be a single entry for any given file.
797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 797 class FetchFileGitStatusesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the Git state of a file with uncommitted changes. # @!attribute [rw] path # @return [::String] # The file's full path including filename, relative to the workspace root. # @!attribute [r] state # @return [::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange::State] # Output only. Indicates the status of the file. class UncommittedFileChange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the status of an uncommitted file change. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The file has been newly added. ADDED = 1 # The file has been deleted. DELETED = 2 # The file has been modified. MODIFIED = 3 # The file contains merge conflicts. HAS_CONFLICTS = 4 end end end |