Class: Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

FetchFileGitStatuses response message.

Defined Under Namespace

Classes: UncommittedFileChange

Instance Attribute Summary collapse

Instance Attribute Details

#uncommitted_file_changes::Array<::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange>

Returns A list of all files which have uncommitted Git changes. There will only be a single entry for any given file.

Returns:



759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 759

class FetchFileGitStatusesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the Git state of a file with uncommitted changes.
  # @!attribute [rw] path
  #   @return [::String]
  #     The file's full path including filename, relative to the workspace root.
  # @!attribute [r] state
  #   @return [::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange::State]
  #     Output only. Indicates the status of the file.
  class UncommittedFileChange
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Indicates the status of an uncommitted file change.
    module State
      # Default value. This value is unused.
      STATE_UNSPECIFIED = 0

      # The file has been newly added.
      ADDED = 1

      # The file has been deleted.
      DELETED = 2

      # The file has been modified.
      MODIFIED = 3

      # The file contains merge conflicts.
      HAS_CONFLICTS = 4
    end
  end
end