Class: Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

FetchFileGitStatuses response message.

Defined Under Namespace

Classes: UncommittedFileChange

Instance Attribute Summary collapse

Instance Attribute Details

#uncommitted_file_changes::Array<::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange>

Returns A list of all files which have uncommitted Git changes. There will only be a single entry for any given file.

Returns:



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 335

class FetchFileGitStatusesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the Git state of a file with uncommitted changes.
  # @!attribute [rw] path
  #   @return [::String]
  #     The file's full path including filename, relative to the workspace root.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange::State]
  #     Indicates the status of the file.
  class UncommittedFileChange
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Indicates the status of an uncommitted file change.
    module State
      # Default value. This value is unused.
      STATE_UNSPECIFIED = 0

      # The file has been newly added.
      ADDED = 1

      # The file has been deleted.
      DELETED = 2

      # The file has been modified.
      MODIFIED = 3

      # The file contains merge conflicts.
      HAS_CONFLICTS = 4
    end
  end
end