Class: Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents the Git state of a file with uncommitted changes.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#path ⇒ ::String
The file's full path including filename, relative to the workspace root.
-
#state ⇒ ::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange::State
Indicates the status of the file.
Instance Attribute Details
#path ⇒ ::String
Returns The file's full path including filename, relative to the workspace root.
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 346 class UncommittedFileChange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the status of an uncommitted file change. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The file has been newly added. ADDED = 1 # The file has been deleted. DELETED = 2 # The file has been modified. MODIFIED = 3 # The file contains merge conflicts. HAS_CONFLICTS = 4 end end |
#state ⇒ ::Google::Cloud::Dataform::V1beta1::FetchFileGitStatusesResponse::UncommittedFileChange::State
Returns Indicates the status of the file.
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 346 class UncommittedFileChange include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the status of an uncommitted file change. module State # Default value. This value is unused. STATE_UNSPECIFIED = 0 # The file has been newly added. ADDED = 1 # The file has been deleted. DELETED = 2 # The file has been modified. MODIFIED = 3 # The file contains merge conflicts. HAS_CONFLICTS = 4 end end |