Class: Google::Cloud::Dataform::V1beta1::InvocationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::InvocationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Includes various configuration options for a workflow invocation.
If both included_targets and included_tags are unset, all actions
will be included.
Defined Under Namespace
Modules: QueryPriority
Instance Attribute Summary collapse
-
#fully_refresh_incremental_tables_enabled ⇒ ::Boolean
Optional.
-
#included_tags ⇒ ::Array<::String>
Optional.
-
#included_targets ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::Target>
Optional.
-
#query_priority ⇒ ::Google::Cloud::Dataform::V1beta1::InvocationConfig::QueryPriority
Optional.
-
#service_account ⇒ ::String
Optional.
-
#transitive_dependencies_included ⇒ ::Boolean
Optional.
-
#transitive_dependents_included ⇒ ::Boolean
Optional.
Instance Attribute Details
#fully_refresh_incremental_tables_enabled ⇒ ::Boolean
Returns Optional. When set to true, any incremental tables will be fully refreshed.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2135 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#included_tags ⇒ ::Array<::String>
Returns Optional. The set of tags to include.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2135 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#included_targets ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::Target>
Returns Optional. The set of action identifiers to include.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2135 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#query_priority ⇒ ::Google::Cloud::Dataform::V1beta1::InvocationConfig::QueryPriority
Returns Optional. Specifies the priority for query execution in BigQuery. More information can be found at https://cloud.google.com/bigquery/docs/running-queries#queries.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2135 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#service_account ⇒ ::String
Returns Optional. The service account to run workflow invocations under.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2135 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#transitive_dependencies_included ⇒ ::Boolean
Returns Optional. When set to true, transitive dependencies of included actions will be executed.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2135 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |
#transitive_dependents_included ⇒ ::Boolean
Returns Optional. When set to true, transitive dependents of included actions will be executed.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2135 class InvocationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Types of priority for query execution in BigQuery. module QueryPriority # Default value. This value is unused. QUERY_PRIORITY_UNSPECIFIED = 0 # Query will be executed in BigQuery with interactive priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#queries. INTERACTIVE = 1 # Query will be executed in BigQuery with batch priority. # More information can be found at # https://cloud.google.com/bigquery/docs/running-queries#batchqueries. BATCH = 2 end end |