Class: Google::Cloud::Dataform::V1beta1::ListCompilationResultsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

ListCompilationResults request message.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. Maximum number of compilation results to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Maximum number of compilation results to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.



759
760
761
762
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 759

class ListCompilationResultsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Page token received from a previous ListCompilationResults call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListCompilationResults must match the call that provided the page token.

Returns:

  • (::String)

    Optional. Page token received from a previous ListCompilationResults call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListCompilationResults must match the call that provided the page token.



759
760
761
762
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 759

class ListCompilationResultsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The repository in which to list compilation results. Must be in the format projects/*/locations/*/repositories/*.

Returns:

  • (::String)

    Required. The repository in which to list compilation results. Must be in the format projects/*/locations/*/repositories/*.



759
760
761
762
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 759

class ListCompilationResultsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end