Class: Google::Cloud::Dataform::V1beta1::MoveFolderMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::MoveFolderMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Contains metadata about the progress of the MoveFolder Long-running operations.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#percent_complete ⇒ ::Integer
Percent complete of the move [0, 100].
-
#state ⇒ ::Google::Cloud::Dataform::V1beta1::MoveFolderMetadata::State
The state of the move.
-
#target ⇒ ::String
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation was created.
3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3300 class MoveFolderMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation finished running.
3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3300 class MoveFolderMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |
#percent_complete ⇒ ::Integer
Returns Percent complete of the move [0, 100].
3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3300 class MoveFolderMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |
#state ⇒ ::Google::Cloud::Dataform::V1beta1::MoveFolderMetadata::State
Returns The state of the move.
3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3300 class MoveFolderMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |
#target ⇒ ::String (readonly)
Returns Output only. Server-defined resource path for the target of the operation.
3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3300 class MoveFolderMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |