Class: Google::Cloud::Dataform::V1beta1::MoveRepositoryMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::MoveRepositoryMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Contains metadata about the progress of the MoveRepository Long-running operations.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#percent_complete ⇒ ::Integer
Percent complete of the move [0, 100].
-
#state ⇒ ::Google::Cloud::Dataform::V1beta1::MoveRepositoryMetadata::State
The state of the move.
-
#target ⇒ ::String
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation was created.
3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3182 class MoveRepositoryMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The time the operation finished running.
3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3182 class MoveRepositoryMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |
#percent_complete ⇒ ::Integer
Returns Percent complete of the move [0, 100].
3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3182 class MoveRepositoryMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |
#state ⇒ ::Google::Cloud::Dataform::V1beta1::MoveRepositoryMetadata::State
Returns The state of the move.
3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3182 class MoveRepositoryMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |
#target ⇒ ::String (readonly)
Returns Output only. Server-defined resource path for the target of the operation.
3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3182 class MoveRepositoryMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Different states of the move. module State # The state is unspecified. STATE_UNSPECIFIED = 0 # The move was initialized and recorded by the server, but not yet started. INITIALIZED = 1 # The move is in progress. IN_PROGRESS = 2 # The move has completed successfully. SUCCESS = 3 # The move has failed. FAILED = 4 end end |