Class: Google::Cloud::Dataform::V1beta1::QueryCompilationResultActionsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::QueryCompilationResultActionsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
QueryCompilationResultActions request message.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#name ⇒ ::String
Required.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Optional filter for the returned list. Filtering is only currently
supported on the file_path field.
1085 1086 1087 1088 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1085 class QueryCompilationResultActionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The compilation result's name.
1085 1086 1087 1088 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1085 class QueryCompilationResultActionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Maximum number of compilation results to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
1085 1086 1087 1088 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1085 class QueryCompilationResultActionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Page token received from a previous QueryCompilationResultActions call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
QueryCompilationResultActions must match the call that provided the page
token.
1085 1086 1087 1088 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1085 class QueryCompilationResultActionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |