Class: Google::Cloud::Dataform::V1beta1::QueryDirectoryContentsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::QueryDirectoryContentsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
QueryDirectoryContents request message.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#path ⇒ ::String
Optional.
-
#workspace ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
783 784 785 786 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 783 class QueryDirectoryContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Page token received from a previous QueryDirectoryContents
call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
QueryDirectoryContents must match the call that provided the page
token.
783 784 785 786 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 783 class QueryDirectoryContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#path ⇒ ::String
Returns Optional. The directory's full path including directory name, relative to the workspace root. If left unset, the workspace root is used.
783 784 785 786 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 783 class QueryDirectoryContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#workspace ⇒ ::String
Returns Required. The workspace's name.
783 784 785 786 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 783 class QueryDirectoryContentsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |