Class: Google::Cloud::Dataform::V1beta1::QueryDirectoryContentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

QueryDirectoryContents request message.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.

Returns:

  • (::Integer)

    Optional. Maximum number of paths to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.



778
779
780
781
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 778

class QueryDirectoryContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Page token received from a previous QueryDirectoryContents call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to QueryDirectoryContents must match the call that provided the page token.

Returns:

  • (::String)

    Optional. Page token received from a previous QueryDirectoryContents call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to QueryDirectoryContents must match the call that provided the page token.



778
779
780
781
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 778

class QueryDirectoryContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#path::String

Returns Optional. The directory's full path including directory name, relative to the workspace root. If left unset, the workspace root is used.

Returns:

  • (::String)

    Optional. The directory's full path including directory name, relative to the workspace root. If left unset, the workspace root is used.



778
779
780
781
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 778

class QueryDirectoryContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#workspace::String

Returns Required. The workspace's name.

Returns:

  • (::String)

    Required. The workspace's name.



778
779
780
781
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 778

class QueryDirectoryContentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end