Class: Google::Cloud::Dataform::V1beta1::QueryDirectoryContentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::QueryDirectoryContentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
QueryDirectoryContents response message.
Defined Under Namespace
Classes: DirectoryEntry
Instance Attribute Summary collapse
-
#directory_entries ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::QueryDirectoryContentsResponse::DirectoryEntry>
List of entries in the directory.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#directory_entries ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::QueryDirectoryContentsResponse::DirectoryEntry>
Returns List of entries in the directory.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 486 class QueryDirectoryContentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single entry in a workspace directory. # @!attribute [rw] file # @return [::String] # A file in the directory. # @!attribute [rw] directory # @return [::String] # A child directory in the directory. class DirectoryEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 486 class QueryDirectoryContentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single entry in a workspace directory. # @!attribute [rw] file # @return [::String] # A file in the directory. # @!attribute [rw] directory # @return [::String] # A child directory in the directory. class DirectoryEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |