Class: Google::Cloud::Dataform::V1beta1::QueryFolderContentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

QueryFolderContents response message.

Defined Under Namespace

Classes: FolderContentsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#entries::Array<::Google::Cloud::Dataform::V1beta1::QueryFolderContentsResponse::FolderContentsEntry>

Returns List of entries in the folder.

Returns:



2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2983

class QueryFolderContentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a single content entry.
  # @!attribute [rw] folder
  #   @return [::Google::Cloud::Dataform::V1beta1::Folder]
  #     A subfolder.
  #
  #     Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] repository
  #   @return [::Google::Cloud::Dataform::V1beta1::Repository]
  #     A repository.
  #
  #     Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class FolderContentsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2983

class QueryFolderContentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a single content entry.
  # @!attribute [rw] folder
  #   @return [::Google::Cloud::Dataform::V1beta1::Folder]
  #     A subfolder.
  #
  #     Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] repository
  #   @return [::Google::Cloud::Dataform::V1beta1::Repository]
  #     A repository.
  #
  #     Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class FolderContentsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end