Class: Google::Cloud::Dataform::V1beta1::QueryTeamFolderContentsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::QueryTeamFolderContentsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
QueryTeamFolderContents response message.
Defined Under Namespace
Classes: TeamFolderContentsEntry
Instance Attribute Summary collapse
-
#entries ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::QueryTeamFolderContentsResponse::TeamFolderContentsEntry>
List of entries in the TeamFolder.
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Attribute Details
#entries ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::QueryTeamFolderContentsResponse::TeamFolderContentsEntry>
Returns List of entries in the TeamFolder.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3201 class QueryTeamFolderContentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single content entry. # @!attribute [rw] folder # @return [::Google::Cloud::Dataform::V1beta1::Folder] # A subfolder. # # Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] repository # @return [::Google::Cloud::Dataform::V1beta1::Repository] # A repository. # # Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared. class TeamFolderContentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3201 class QueryTeamFolderContentsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single content entry. # @!attribute [rw] folder # @return [::Google::Cloud::Dataform::V1beta1::Folder] # A subfolder. # # Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] repository # @return [::Google::Cloud::Dataform::V1beta1::Repository] # A repository. # # Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared. class TeamFolderContentsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |