Class: Google::Cloud::Dataform::V1beta1::QueryUserRootContentsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

QueryUserRootContents response message.

Defined Under Namespace

Classes: RootContentsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#entries::Array<::Google::Cloud::Dataform::V1beta1::QueryUserRootContentsResponse::RootContentsEntry>

Returns List of entries in the folder.

Returns:



3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3052

class QueryUserRootContentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a single content entry.
  # @!attribute [rw] folder
  #   @return [::Google::Cloud::Dataform::V1beta1::Folder]
  #     A subfolder.
  #
  #     Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] repository
  #   @return [::Google::Cloud::Dataform::V1beta1::Repository]
  #     A repository.
  #
  #     Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class RootContentsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3052

class QueryUserRootContentsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a single content entry.
  # @!attribute [rw] folder
  #   @return [::Google::Cloud::Dataform::V1beta1::Folder]
  #     A subfolder.
  #
  #     Note: The following fields are mutually exclusive: `folder`, `repository`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  # @!attribute [rw] repository
  #   @return [::Google::Cloud::Dataform::V1beta1::Repository]
  #     A repository.
  #
  #     Note: The following fields are mutually exclusive: `repository`, `folder`. If a field in that set is populated, all other fields in the set will automatically be cleared.
  class RootContentsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end