Class: Google::Cloud::Dataform::V1beta1::QueryWorkflowInvocationActionsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::QueryWorkflowInvocationActionsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
QueryWorkflowInvocationActions request message.
Instance Attribute Summary collapse
-
#name ⇒ ::String
Required.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
Instance Attribute Details
#name ⇒ ::String
Returns Required. The workflow invocation's name.
1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1331 class QueryWorkflowInvocationActionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Maximum number of workflow invocations to return. The server may return fewer items than requested. If unspecified, the server will pick an appropriate default.
1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1331 class QueryWorkflowInvocationActionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. Page token received from a previous QueryWorkflowInvocationActions call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to
QueryWorkflowInvocationActions must match the call that provided the page
token.
1331 1332 1333 1334 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1331 class QueryWorkflowInvocationActionsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |