Class: Google::Cloud::Dataform::V1beta1::RelationDescriptor

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Describes a relation and its columns.

Defined Under Namespace

Classes: BigqueryLabelsEntry, ColumnDescriptor

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_labels::Google::Protobuf::Map{::String => ::String}

Returns A set of BigQuery labels that should be applied to the relation.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    A set of BigQuery labels that should be applied to the relation.



1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1648

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#columns::Array<::Google::Cloud::Dataform::V1beta1::RelationDescriptor::ColumnDescriptor>

Returns A list of descriptions of columns within the relation.

Returns:



1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1648

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns A text description of the relation.

Returns:

  • (::String)

    A text description of the relation.



1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1648

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end