Class: Google::Cloud::Dataform::V1beta1::RelationDescriptor

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Describes a relation and its columns.

Defined Under Namespace

Classes: BigqueryLabelsEntry, ColumnDescriptor

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_labels::Google::Protobuf::Map{::String => ::String}

Returns A set of BigQuery labels that should be applied to the relation.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    A set of BigQuery labels that should be applied to the relation.



1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1314

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#columns::Array<::Google::Cloud::Dataform::V1beta1::RelationDescriptor::ColumnDescriptor>

Returns A list of descriptions of columns within the relation.

Returns:



1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1314

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns A text description of the relation.

Returns:

  • (::String)

    A text description of the relation.



1314
1315
1316
1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1314

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end