Class: Google::Cloud::Dataform::V1beta1::RelationDescriptor

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Describes a relation and its columns.

Defined Under Namespace

Classes: BigqueryLabelsEntry, ColumnDescriptor

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_labels::Google::Protobuf::Map{::String => ::String}

Returns A set of BigQuery labels that should be applied to the relation.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    A set of BigQuery labels that should be applied to the relation.



828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 828

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#columns::Array<::Google::Cloud::Dataform::V1beta1::RelationDescriptor::ColumnDescriptor>

Returns A list of descriptions of columns within the relation.

Returns:



828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 828

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String

Returns A text description of the relation.

Returns:

  • (::String)

    A text description of the relation.



828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 828

class RelationDescriptor
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Describes a column.
  # @!attribute [rw] path
  #   @return [::Array<::String>]
  #     The identifier for the column. Each entry in `path` represents one level
  #     of nesting.
  # @!attribute [rw] description
  #   @return [::String]
  #     A textual description of the column.
  # @!attribute [rw] bigquery_policy_tags
  #   @return [::Array<::String>]
  #     A list of BigQuery policy tags that will be applied to the column.
  class ColumnDescriptor
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class BigqueryLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end