Class: Google::Cloud::Dataform::V1beta1::Repository
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::Repository
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a Dataform Git repository.
Defined Under Namespace
Classes: GitRemoteSettings
Instance Attribute Summary collapse
-
#git_remote_settings ⇒ ::Google::Cloud::Dataform::V1beta1::Repository::GitRemoteSettings
Optional.
-
#name ⇒ ::String
readonly
Output only.
Instance Attribute Details
#git_remote_settings ⇒ ::Google::Cloud::Dataform::V1beta1::Repository::GitRemoteSettings
Returns Optional. If set, configures this repository to be linked to a Git remote.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 31 class Repository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls Git remote configuration for a repository. # @!attribute [rw] url # @return [::String] # Required. The Git remote's URL. # @!attribute [rw] default_branch # @return [::String] # Required. The Git remote's default branch name. # @!attribute [rw] authentication_token_secret_version # @return [::String] # Required. The name of the Secret Manager secret version to use as an # authentication token for Git operations. Must be in the format # `projects/*/secrets/*/versions/*`. # @!attribute [r] token_status # @return [::Google::Cloud::Dataform::V1beta1::Repository::GitRemoteSettings::TokenStatus] # Output only. Indicates the status of the Git access token. class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the status of a Git authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end end |
#name ⇒ ::String (readonly)
Returns Output only. The repository's name.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 31 class Repository include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Controls Git remote configuration for a repository. # @!attribute [rw] url # @return [::String] # Required. The Git remote's URL. # @!attribute [rw] default_branch # @return [::String] # Required. The Git remote's default branch name. # @!attribute [rw] authentication_token_secret_version # @return [::String] # Required. The name of the Secret Manager secret version to use as an # authentication token for Git operations. Must be in the format # `projects/*/secrets/*/versions/*`. # @!attribute [r] token_status # @return [::Google::Cloud::Dataform::V1beta1::Repository::GitRemoteSettings::TokenStatus] # Output only. Indicates the status of the Git access token. class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the status of a Git authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end end |