Class: Google::Cloud::Dataform::V1beta1::Repository::GitRemoteSettings
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::Repository::GitRemoteSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Controls Git remote configuration for a repository.
Defined Under Namespace
Modules: TokenStatus
Instance Attribute Summary collapse
-
#authentication_token_secret_version ⇒ ::String
Required.
-
#default_branch ⇒ ::String
Required.
-
#token_status ⇒ ::Google::Cloud::Dataform::V1beta1::Repository::GitRemoteSettings::TokenStatus
readonly
Output only.
-
#url ⇒ ::String
Required.
Instance Attribute Details
#authentication_token_secret_version ⇒ ::String
Returns Required. The name of the Secret Manager secret version to use as an
authentication token for Git operations. Must be in the format
projects/*/secrets/*/versions/*.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 50 class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the status of a Git authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end |
#default_branch ⇒ ::String
Returns Required. The Git remote's default branch name.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 50 class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the status of a Git authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end |
#token_status ⇒ ::Google::Cloud::Dataform::V1beta1::Repository::GitRemoteSettings::TokenStatus (readonly)
Returns Output only. Indicates the status of the Git access token.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 50 class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the status of a Git authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end |
#url ⇒ ::String
Returns Required. The Git remote's URL.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 50 class GitRemoteSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Indicates the status of a Git authentication token. module TokenStatus # Default value. This value is unused. TOKEN_STATUS_UNSPECIFIED = 0 # The token could not be found in Secret Manager (or the Dataform # Service Account did not have permission to access it). NOT_FOUND = 1 # The token could not be used to authenticate against the Git remote. INVALID = 2 # The token was used successfully to authenticate against the Git remote. VALID = 3 end end |