Class: Google::Cloud::Dataform::V1beta1::SearchTeamFoldersResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::SearchTeamFoldersResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
SearchTeamFolders response message.
Defined Under Namespace
Classes: TeamFolderSearchResult
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#results ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::SearchTeamFoldersResponse::TeamFolderSearchResult>
List of TeamFolders that match the search query.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3111 class SearchTeamFoldersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single content entry. # @!attribute [rw] team_folder # @return [::Google::Cloud::Dataform::V1beta1::TeamFolder] # A TeamFolder resource that is in the project / location. class TeamFolderSearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#results ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::SearchTeamFoldersResponse::TeamFolderSearchResult>
Returns List of TeamFolders that match the search query.
3111 3112 3113 3114 3115 3116 3117 3118 3119 3120 3121 3122 3123 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 3111 class SearchTeamFoldersResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a single content entry. # @!attribute [rw] team_folder # @return [::Google::Cloud::Dataform::V1beta1::TeamFolder] # A TeamFolder resource that is in the project / location. class TeamFolderSearchResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |