Class: Google::Cloud::Dataform::V1beta1::TriggerEvaluationRecord
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::TriggerEvaluationRecord
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
A record of an attempt to evaluate trigger conditions.
Instance Attribute Summary collapse
-
#evaluation_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#status ⇒ ::Google::Rpc::Status
readonly
Output only.
Instance Attribute Details
#evaluation_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of this trigger evaluation attempt.
1549 1550 1551 1552 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1549 class TriggerEvaluationRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#status ⇒ ::Google::Rpc::Status (readonly)
Returns Output only. The status of the trigger evaluation. Success is indicated by a code of 0 (OK). Message will only be present if the status code is non-zero.
1549 1550 1551 1552 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1549 class TriggerEvaluationRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |