Class: Google::Cloud::Dataform::V1beta1::WorkflowConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::WorkflowConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a Dataform workflow configuration.
Defined Under Namespace
Classes: ScheduledExecutionRecord
Instance Attribute Summary collapse
-
#cron_schedule ⇒ ::String
Optional.
-
#invocation_config ⇒ ::Google::Cloud::Dataform::V1beta1::InvocationConfig
Optional.
-
#name ⇒ ::String
readonly
Output only.
-
#recent_scheduled_execution_records ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::WorkflowConfig::ScheduledExecutionRecord>
readonly
Output only.
-
#release_config ⇒ ::String
Required.
-
#time_zone ⇒ ::String
Optional.
Instance Attribute Details
#cron_schedule ⇒ ::String
Returns Optional. Optional schedule (in cron format) for automatic execution of this workflow config.
1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1625 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] execution_time # @return [::Google::Protobuf::Timestamp] # The timestamp of this execution attempt. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#invocation_config ⇒ ::Google::Cloud::Dataform::V1beta1::InvocationConfig
Returns Optional. If left unset, a default InvocationConfig will be used.
1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1625 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] execution_time # @return [::Google::Protobuf::Timestamp] # The timestamp of this execution attempt. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String (readonly)
Returns Output only. The workflow config's name.
1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1625 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] execution_time # @return [::Google::Protobuf::Timestamp] # The timestamp of this execution attempt. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#recent_scheduled_execution_records ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::WorkflowConfig::ScheduledExecutionRecord> (readonly)
Returns Output only. Records of the 10 most recent scheduled execution attempts,
ordered in in descending order of execution_time. Updated whenever
automatic creation of a workflow invocation is triggered by cron_schedule.
1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1625 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] execution_time # @return [::Google::Protobuf::Timestamp] # The timestamp of this execution attempt. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#release_config ⇒ ::String
Returns Required. The name of the release config whose release_compilation_result
should be executed. Must be in the format
projects/*/locations/*/repositories/*/releaseConfigs/*.
1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1625 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] execution_time # @return [::Google::Protobuf::Timestamp] # The timestamp of this execution attempt. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#time_zone ⇒ ::String
Returns Optional. Specifies the time zone to be used when interpreting cron_schedule. Must be a time zone name from the time zone database (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones). If left unspecified, the default is UTC.
1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1625 class WorkflowConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # A record of an attempt to create a workflow invocation for this workflow # config. # @!attribute [rw] execution_time # @return [::Google::Protobuf::Timestamp] # The timestamp of this execution attempt. # @!attribute [rw] workflow_invocation # @return [::String] # The name of the created workflow invocation, if one was successfully # created. Must be in the format # `projects/*/locations/*/repositories/*/workflowInvocations/*`. # # Note: The following fields are mutually exclusive: `workflow_invocation`, `error_status`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] error_status # @return [::Google::Rpc::Status] # The error status encountered upon this attempt to create the # workflow invocation, if the attempt was unsuccessful. # # Note: The following fields are mutually exclusive: `error_status`, `workflow_invocation`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ScheduledExecutionRecord include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |