Class: Google::Cloud::Dataform::V1beta1::WorkflowInvocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents a single invocation of a compilation result.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#compilation_result::String

Returns Immutable. The name of the compilation result to use for this invocation. Must be in the format projects/*/locations/*/repositories/*/compilationResults/*.

Note: The following fields are mutually exclusive: compilation_result, workflow_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Immutable. The name of the compilation result to use for this invocation. Must be in the format projects/*/locations/*/repositories/*/compilationResults/*.

    Note: The following fields are mutually exclusive: compilation_result, workflow_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1793

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end

#invocation_config::Google::Cloud::Dataform::V1beta1::InvocationConfig

Returns Immutable. If left unset, a default InvocationConfig will be used.

Returns:



1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1793

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end

#invocation_timing::Google::Type::Interval (readonly)

Returns Output only. This workflow invocation's timing details.

Returns:



1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1793

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end

#name::String (readonly)

Returns Output only. The workflow invocation's name.

Returns:

  • (::String)

    Output only. The workflow invocation's name.



1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1793

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end

#state::Google::Cloud::Dataform::V1beta1::WorkflowInvocation::State (readonly)

Returns Output only. This workflow invocation's current state.

Returns:



1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1793

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end

#workflow_config::String

Returns Immutable. The name of the workflow config to invoke. Must be in the format projects/*/locations/*/repositories/*/workflowConfigs/*.

Note: The following fields are mutually exclusive: workflow_config, compilation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Immutable. The name of the workflow config to invoke. Must be in the format projects/*/locations/*/repositories/*/workflowConfigs/*.

    Note: The following fields are mutually exclusive: workflow_config, compilation_result. If a field in that set is populated, all other fields in the set will automatically be cleared.



1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1793

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end