Class: Google::Cloud::Dataform::V1beta1::WorkflowInvocation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents a single invocation of a compilation result.

Defined Under Namespace

Modules: State Classes: InvocationConfig

Instance Attribute Summary collapse

Instance Attribute Details

#compilation_result::String

Returns Immutable. The name of the compilation result to compile. Must be in the format projects/*/locations/*/repositories/*/compilationResults/*.

Returns:

  • (::String)

    Immutable. The name of the compilation result to compile. Must be in the format projects/*/locations/*/repositories/*/compilationResults/*.



1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1120

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Includes various configuration options for this workflow invocation.
  # If both `included_targets` and `included_tags` are unset, all actions
  # will be included.
  # @!attribute [rw] included_targets
  #   @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>]
  #     Immutable. The set of action identifiers to include.
  # @!attribute [rw] included_tags
  #   @return [::Array<::String>]
  #     Immutable. The set of tags to include.
  # @!attribute [rw] transitive_dependencies_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependencies of included actions will be
  #     executed.
  # @!attribute [rw] transitive_dependents_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependents of included actions will be
  #     executed.
  # @!attribute [rw] fully_refresh_incremental_tables_enabled
  #   @return [::Boolean]
  #     Immutable. When set to true, any incremental tables will be fully refreshed.
  class InvocationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end

#invocation_config::Google::Cloud::Dataform::V1beta1::WorkflowInvocation::InvocationConfig

Returns Immutable. If left unset, a default InvocationConfig will be used.

Returns:



1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1120

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Includes various configuration options for this workflow invocation.
  # If both `included_targets` and `included_tags` are unset, all actions
  # will be included.
  # @!attribute [rw] included_targets
  #   @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>]
  #     Immutable. The set of action identifiers to include.
  # @!attribute [rw] included_tags
  #   @return [::Array<::String>]
  #     Immutable. The set of tags to include.
  # @!attribute [rw] transitive_dependencies_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependencies of included actions will be
  #     executed.
  # @!attribute [rw] transitive_dependents_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependents of included actions will be
  #     executed.
  # @!attribute [rw] fully_refresh_incremental_tables_enabled
  #   @return [::Boolean]
  #     Immutable. When set to true, any incremental tables will be fully refreshed.
  class InvocationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end

#invocation_timing::Google::Type::Interval (readonly)

Returns Output only. This workflow invocation's timing details.

Returns:



1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1120

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Includes various configuration options for this workflow invocation.
  # If both `included_targets` and `included_tags` are unset, all actions
  # will be included.
  # @!attribute [rw] included_targets
  #   @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>]
  #     Immutable. The set of action identifiers to include.
  # @!attribute [rw] included_tags
  #   @return [::Array<::String>]
  #     Immutable. The set of tags to include.
  # @!attribute [rw] transitive_dependencies_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependencies of included actions will be
  #     executed.
  # @!attribute [rw] transitive_dependents_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependents of included actions will be
  #     executed.
  # @!attribute [rw] fully_refresh_incremental_tables_enabled
  #   @return [::Boolean]
  #     Immutable. When set to true, any incremental tables will be fully refreshed.
  class InvocationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end

#name::String (readonly)

Returns Output only. The workflow invocation's name.

Returns:

  • (::String)

    Output only. The workflow invocation's name.



1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1120

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Includes various configuration options for this workflow invocation.
  # If both `included_targets` and `included_tags` are unset, all actions
  # will be included.
  # @!attribute [rw] included_targets
  #   @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>]
  #     Immutable. The set of action identifiers to include.
  # @!attribute [rw] included_tags
  #   @return [::Array<::String>]
  #     Immutable. The set of tags to include.
  # @!attribute [rw] transitive_dependencies_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependencies of included actions will be
  #     executed.
  # @!attribute [rw] transitive_dependents_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependents of included actions will be
  #     executed.
  # @!attribute [rw] fully_refresh_incremental_tables_enabled
  #   @return [::Boolean]
  #     Immutable. When set to true, any incremental tables will be fully refreshed.
  class InvocationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end

#state::Google::Cloud::Dataform::V1beta1::WorkflowInvocation::State (readonly)

Returns Output only. This workflow invocation's current state.

Returns:



1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
1153
1154
1155
1156
1157
1158
1159
1160
1161
1162
1163
1164
1165
1166
1167
1168
1169
1170
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1120

class WorkflowInvocation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Includes various configuration options for this workflow invocation.
  # If both `included_targets` and `included_tags` are unset, all actions
  # will be included.
  # @!attribute [rw] included_targets
  #   @return [::Array<::Google::Cloud::Dataform::V1beta1::Target>]
  #     Immutable. The set of action identifiers to include.
  # @!attribute [rw] included_tags
  #   @return [::Array<::String>]
  #     Immutable. The set of tags to include.
  # @!attribute [rw] transitive_dependencies_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependencies of included actions will be
  #     executed.
  # @!attribute [rw] transitive_dependents_included
  #   @return [::Boolean]
  #     Immutable. When set to true, transitive dependents of included actions will be
  #     executed.
  # @!attribute [rw] fully_refresh_incremental_tables_enabled
  #   @return [::Boolean]
  #     Immutable. When set to true, any incremental tables will be fully refreshed.
  class InvocationConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of a workflow invocation.
  module State
    # Default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The workflow invocation is currently running.
    RUNNING = 1

    # The workflow invocation succeeded. A terminal state.
    SUCCEEDED = 2

    # The workflow invocation was cancelled. A terminal state.
    CANCELLED = 3

    # The workflow invocation failed. A terminal state.
    FAILED = 4

    # The workflow invocation is being cancelled, but some actions are still
    # running.
    CANCELING = 5
  end
end