Class: Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a single action in a workflow invocation.
Defined Under Namespace
Modules: State Classes: BigQueryAction
Instance Attribute Summary collapse
-
#bigquery_action ⇒ ::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::BigQueryAction
readonly
Output only.
-
#canonical_target ⇒ ::Google::Cloud::Dataform::V1beta1::Target
readonly
Output only.
-
#failure_reason ⇒ ::String
readonly
Output only.
-
#invocation_timing ⇒ ::Google::Type::Interval
readonly
Output only.
-
#state ⇒ ::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::State
readonly
Output only.
-
#target ⇒ ::Google::Cloud::Dataform::V1beta1::Target
readonly
Output only.
Instance Attribute Details
#bigquery_action ⇒ ::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::BigQueryAction (readonly)
Returns Output only. The workflow action's bigquery action details.
1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1932 class WorkflowInvocationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a workflow action that will run against BigQuery. # @!attribute [r] sql_script # @return [::String] # Output only. The generated BigQuery SQL script that will be executed. class BigQueryAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the current state of a workflow invocation action. module State # The action has not yet been considered for invocation. PENDING = 0 # The action is currently running. RUNNING = 1 # Execution of the action was skipped because upstream dependencies did not # all complete successfully. A terminal state. SKIPPED = 2 # Execution of the action was disabled as per the configuration of the # corresponding compilation result action. A terminal state. DISABLED = 3 # The action succeeded. A terminal state. SUCCEEDED = 4 # The action was cancelled. A terminal state. CANCELLED = 5 # The action failed. A terminal state. FAILED = 6 end end |
#canonical_target ⇒ ::Google::Cloud::Dataform::V1beta1::Target (readonly)
Returns Output only. The action's identifier if the project had been compiled without any overrides configured. Unique within the compilation result.
1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1932 class WorkflowInvocationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a workflow action that will run against BigQuery. # @!attribute [r] sql_script # @return [::String] # Output only. The generated BigQuery SQL script that will be executed. class BigQueryAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the current state of a workflow invocation action. module State # The action has not yet been considered for invocation. PENDING = 0 # The action is currently running. RUNNING = 1 # Execution of the action was skipped because upstream dependencies did not # all complete successfully. A terminal state. SKIPPED = 2 # Execution of the action was disabled as per the configuration of the # corresponding compilation result action. A terminal state. DISABLED = 3 # The action succeeded. A terminal state. SUCCEEDED = 4 # The action was cancelled. A terminal state. CANCELLED = 5 # The action failed. A terminal state. FAILED = 6 end end |
#failure_reason ⇒ ::String (readonly)
Returns Output only. If and only if action's state is FAILED a failure reason is set.
1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1932 class WorkflowInvocationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a workflow action that will run against BigQuery. # @!attribute [r] sql_script # @return [::String] # Output only. The generated BigQuery SQL script that will be executed. class BigQueryAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the current state of a workflow invocation action. module State # The action has not yet been considered for invocation. PENDING = 0 # The action is currently running. RUNNING = 1 # Execution of the action was skipped because upstream dependencies did not # all complete successfully. A terminal state. SKIPPED = 2 # Execution of the action was disabled as per the configuration of the # corresponding compilation result action. A terminal state. DISABLED = 3 # The action succeeded. A terminal state. SUCCEEDED = 4 # The action was cancelled. A terminal state. CANCELLED = 5 # The action failed. A terminal state. FAILED = 6 end end |
#invocation_timing ⇒ ::Google::Type::Interval (readonly)
Returns Output only. This action's timing details.
start_time will be set if the action is in [RUNNING, SUCCEEDED,
CANCELLED, FAILED] state.
end_time will be set if the action is in [SUCCEEDED, CANCELLED, FAILED]
state.
1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1932 class WorkflowInvocationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a workflow action that will run against BigQuery. # @!attribute [r] sql_script # @return [::String] # Output only. The generated BigQuery SQL script that will be executed. class BigQueryAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the current state of a workflow invocation action. module State # The action has not yet been considered for invocation. PENDING = 0 # The action is currently running. RUNNING = 1 # Execution of the action was skipped because upstream dependencies did not # all complete successfully. A terminal state. SKIPPED = 2 # Execution of the action was disabled as per the configuration of the # corresponding compilation result action. A terminal state. DISABLED = 3 # The action succeeded. A terminal state. SUCCEEDED = 4 # The action was cancelled. A terminal state. CANCELLED = 5 # The action failed. A terminal state. FAILED = 6 end end |
#state ⇒ ::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::State (readonly)
Returns Output only. This action's current state.
1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1932 class WorkflowInvocationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a workflow action that will run against BigQuery. # @!attribute [r] sql_script # @return [::String] # Output only. The generated BigQuery SQL script that will be executed. class BigQueryAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the current state of a workflow invocation action. module State # The action has not yet been considered for invocation. PENDING = 0 # The action is currently running. RUNNING = 1 # Execution of the action was skipped because upstream dependencies did not # all complete successfully. A terminal state. SKIPPED = 2 # Execution of the action was disabled as per the configuration of the # corresponding compilation result action. A terminal state. DISABLED = 3 # The action succeeded. A terminal state. SUCCEEDED = 4 # The action was cancelled. A terminal state. CANCELLED = 5 # The action failed. A terminal state. FAILED = 6 end end |
#target ⇒ ::Google::Cloud::Dataform::V1beta1::Target (readonly)
Returns Output only. This action's identifier. Unique within the workflow invocation.
1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1932 class WorkflowInvocationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a workflow action that will run against BigQuery. # @!attribute [r] sql_script # @return [::String] # Output only. The generated BigQuery SQL script that will be executed. class BigQueryAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Represents the current state of a workflow invocation action. module State # The action has not yet been considered for invocation. PENDING = 0 # The action is currently running. RUNNING = 1 # Execution of the action was skipped because upstream dependencies did not # all complete successfully. A terminal state. SKIPPED = 2 # Execution of the action was disabled as per the configuration of the # corresponding compilation result action. A terminal state. DISABLED = 3 # The action succeeded. A terminal state. SUCCEEDED = 4 # The action was cancelled. A terminal state. CANCELLED = 5 # The action failed. A terminal state. FAILED = 6 end end |