Class: Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/dataform/v1beta1/dataform.rb

Overview

Represents a single action in a workflow invocation.

Defined Under Namespace

Modules: State Classes: BigQueryAction

Instance Attribute Summary collapse

Instance Attribute Details

#bigquery_action::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::BigQueryAction (readonly)

Returns Output only. The workflow action's bigquery action details.

Returns:



1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1274

class WorkflowInvocationAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a workflow action that will run against BigQuery.
  # @!attribute [r] sql_script
  #   @return [::String]
  #     Output only. The generated BigQuery SQL script that will be executed.
  class BigQueryAction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of an workflow invocation action.
  module State
    # The action has not yet been considered for invocation.
    PENDING = 0

    # The action is currently running.
    RUNNING = 1

    # Execution of the action was skipped because upstream dependencies did not
    # all complete successfully. A terminal state.
    SKIPPED = 2

    # Execution of the action was disabled as per the configuration of the
    # corresponding compilation result action. A terminal state.
    DISABLED = 3

    # The action succeeded. A terminal state.
    SUCCEEDED = 4

    # The action was cancelled. A terminal state.
    CANCELLED = 5

    # The action failed. A terminal state.
    FAILED = 6
  end
end

#canonical_target::Google::Cloud::Dataform::V1beta1::Target (readonly)

Returns Output only. The action's identifier if the project had been compiled without any overrides configured. Unique within the compilation result.

Returns:



1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1274

class WorkflowInvocationAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a workflow action that will run against BigQuery.
  # @!attribute [r] sql_script
  #   @return [::String]
  #     Output only. The generated BigQuery SQL script that will be executed.
  class BigQueryAction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of an workflow invocation action.
  module State
    # The action has not yet been considered for invocation.
    PENDING = 0

    # The action is currently running.
    RUNNING = 1

    # Execution of the action was skipped because upstream dependencies did not
    # all complete successfully. A terminal state.
    SKIPPED = 2

    # Execution of the action was disabled as per the configuration of the
    # corresponding compilation result action. A terminal state.
    DISABLED = 3

    # The action succeeded. A terminal state.
    SUCCEEDED = 4

    # The action was cancelled. A terminal state.
    CANCELLED = 5

    # The action failed. A terminal state.
    FAILED = 6
  end
end

#failure_reason::String (readonly)

Returns Output only. If and only if action's state is FAILED a failure reason is set.

Returns:

  • (::String)

    Output only. If and only if action's state is FAILED a failure reason is set.



1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1274

class WorkflowInvocationAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a workflow action that will run against BigQuery.
  # @!attribute [r] sql_script
  #   @return [::String]
  #     Output only. The generated BigQuery SQL script that will be executed.
  class BigQueryAction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of an workflow invocation action.
  module State
    # The action has not yet been considered for invocation.
    PENDING = 0

    # The action is currently running.
    RUNNING = 1

    # Execution of the action was skipped because upstream dependencies did not
    # all complete successfully. A terminal state.
    SKIPPED = 2

    # Execution of the action was disabled as per the configuration of the
    # corresponding compilation result action. A terminal state.
    DISABLED = 3

    # The action succeeded. A terminal state.
    SUCCEEDED = 4

    # The action was cancelled. A terminal state.
    CANCELLED = 5

    # The action failed. A terminal state.
    FAILED = 6
  end
end

#invocation_timing::Google::Type::Interval (readonly)

Returns Output only. This action's timing details. start_time will be set if the action is in [RUNNING, SUCCEEDED, CANCELLED, FAILED] state. end_time will be set if the action is in [SUCCEEDED, CANCELLED, FAILED] state.

Returns:

  • (::Google::Type::Interval)

    Output only. This action's timing details. start_time will be set if the action is in [RUNNING, SUCCEEDED, CANCELLED, FAILED] state. end_time will be set if the action is in [SUCCEEDED, CANCELLED, FAILED] state.



1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1274

class WorkflowInvocationAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a workflow action that will run against BigQuery.
  # @!attribute [r] sql_script
  #   @return [::String]
  #     Output only. The generated BigQuery SQL script that will be executed.
  class BigQueryAction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of an workflow invocation action.
  module State
    # The action has not yet been considered for invocation.
    PENDING = 0

    # The action is currently running.
    RUNNING = 1

    # Execution of the action was skipped because upstream dependencies did not
    # all complete successfully. A terminal state.
    SKIPPED = 2

    # Execution of the action was disabled as per the configuration of the
    # corresponding compilation result action. A terminal state.
    DISABLED = 3

    # The action succeeded. A terminal state.
    SUCCEEDED = 4

    # The action was cancelled. A terminal state.
    CANCELLED = 5

    # The action failed. A terminal state.
    FAILED = 6
  end
end

#state::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::State (readonly)

Returns Output only. This action's current state.

Returns:



1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1274

class WorkflowInvocationAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a workflow action that will run against BigQuery.
  # @!attribute [r] sql_script
  #   @return [::String]
  #     Output only. The generated BigQuery SQL script that will be executed.
  class BigQueryAction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of an workflow invocation action.
  module State
    # The action has not yet been considered for invocation.
    PENDING = 0

    # The action is currently running.
    RUNNING = 1

    # Execution of the action was skipped because upstream dependencies did not
    # all complete successfully. A terminal state.
    SKIPPED = 2

    # Execution of the action was disabled as per the configuration of the
    # corresponding compilation result action. A terminal state.
    DISABLED = 3

    # The action succeeded. A terminal state.
    SUCCEEDED = 4

    # The action was cancelled. A terminal state.
    CANCELLED = 5

    # The action failed. A terminal state.
    FAILED = 6
  end
end

#target::Google::Cloud::Dataform::V1beta1::Target (readonly)

Returns Output only. This action's identifier. Unique within the workflow invocation.

Returns:



1274
1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
1298
1299
1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1274

class WorkflowInvocationAction
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Represents a workflow action that will run against BigQuery.
  # @!attribute [r] sql_script
  #   @return [::String]
  #     Output only. The generated BigQuery SQL script that will be executed.
  class BigQueryAction
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Represents the current state of an workflow invocation action.
  module State
    # The action has not yet been considered for invocation.
    PENDING = 0

    # The action is currently running.
    RUNNING = 1

    # Execution of the action was skipped because upstream dependencies did not
    # all complete successfully. A terminal state.
    SKIPPED = 2

    # Execution of the action was disabled as per the configuration of the
    # corresponding compilation result action. A terminal state.
    DISABLED = 3

    # The action succeeded. A terminal state.
    SUCCEEDED = 4

    # The action was cancelled. A terminal state.
    CANCELLED = 5

    # The action failed. A terminal state.
    FAILED = 6
  end
end