Class: Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a workflow action that will run a Data Preparation.
Defined Under Namespace
Classes: ActionErrorTable, ActionIncrementalLoadMode, ActionLoadConfig, ActionSimpleLoadMode, ActionSqlDefinition
Instance Attribute Summary collapse
-
#contents_sql ⇒ ::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSqlDefinition
SQL definition for a Data Preparation.
-
#contents_yaml ⇒ ::String
readonly
Output only.
-
#generated_sql ⇒ ::String
readonly
Output only.
-
#job_id ⇒ ::String
readonly
Output only.
Instance Attribute Details
#contents_sql ⇒ ::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSqlDefinition
Returns SQL definition for a Data Preparation. Contains a SQL query and additional context information.
Note: The following fields are mutually exclusive: contents_sql, contents_yaml. If a field in that set is populated, all other fields in the set will automatically be cleared.
2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2502 class DataPreparationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionErrorTable] # Error table configuration, # @!attribute [rw] load_config # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionLoadConfig] # Load configuration. class ActionSqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ActionErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simplified load configuration for actions # @!attribute [rw] replace # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Replace destination table # # Note: The following fields are mutually exclusive: `replace`, `append`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] append # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Append into destination table # # Note: The following fields are mutually exclusive: `append`, `replace`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] maximum # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value exceeds the previous maximum value for # a column in the destination table # # Note: The following fields are mutually exclusive: `maximum`, `replace`, `append`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] unique # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value of a column is not already present in # the destination table # # Note: The following fields are mutually exclusive: `unique`, `replace`, `append`, `maximum`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ActionLoadConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simple load definition class ActionSimpleLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Load definition for incremental load modes # @!attribute [rw] column # @return [::String] # Column name for incremental load modes class ActionIncrementalLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#contents_yaml ⇒ ::String (readonly)
Returns Output only. YAML representing the contents of the data preparation. Can be used to show the customer what the input was to their workflow.
Note: The following fields are mutually exclusive: contents_yaml, contents_sql. If a field in that set is populated, all other fields in the set will automatically be cleared.
2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2502 class DataPreparationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionErrorTable] # Error table configuration, # @!attribute [rw] load_config # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionLoadConfig] # Load configuration. class ActionSqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ActionErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simplified load configuration for actions # @!attribute [rw] replace # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Replace destination table # # Note: The following fields are mutually exclusive: `replace`, `append`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] append # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Append into destination table # # Note: The following fields are mutually exclusive: `append`, `replace`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] maximum # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value exceeds the previous maximum value for # a column in the destination table # # Note: The following fields are mutually exclusive: `maximum`, `replace`, `append`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] unique # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value of a column is not already present in # the destination table # # Note: The following fields are mutually exclusive: `unique`, `replace`, `append`, `maximum`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ActionLoadConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simple load definition class ActionSimpleLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Load definition for incremental load modes # @!attribute [rw] column # @return [::String] # Column name for incremental load modes class ActionIncrementalLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#generated_sql ⇒ ::String (readonly)
Returns Output only. The generated BigQuery SQL script that will be executed. For reference only.
2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2502 class DataPreparationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionErrorTable] # Error table configuration, # @!attribute [rw] load_config # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionLoadConfig] # Load configuration. class ActionSqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ActionErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simplified load configuration for actions # @!attribute [rw] replace # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Replace destination table # # Note: The following fields are mutually exclusive: `replace`, `append`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] append # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Append into destination table # # Note: The following fields are mutually exclusive: `append`, `replace`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] maximum # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value exceeds the previous maximum value for # a column in the destination table # # Note: The following fields are mutually exclusive: `maximum`, `replace`, `append`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] unique # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value of a column is not already present in # the destination table # # Note: The following fields are mutually exclusive: `unique`, `replace`, `append`, `maximum`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ActionLoadConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simple load definition class ActionSimpleLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Load definition for incremental load modes # @!attribute [rw] column # @return [::String] # Column name for incremental load modes class ActionIncrementalLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#job_id ⇒ ::String (readonly)
Returns Output only. The ID of the BigQuery job that executed the SQL in sql_script. Only set once the job has started to run.
2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2502 class DataPreparationAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Definition of a SQL Data Preparation # @!attribute [rw] query # @return [::String] # The SQL query representing the data preparation steps. Formatted as a # Pipe SQL query statement. # @!attribute [rw] error_table # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionErrorTable] # Error table configuration, # @!attribute [rw] load_config # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionLoadConfig] # Load configuration. class ActionSqlDefinition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Error table information, used to write error data into a BigQuery # table. # @!attribute [rw] target # @return [::Google::Cloud::Dataform::V1beta1::Target] # Error Table target. # @!attribute [rw] retention_days # @return [::Integer] # Error table partition expiration in days. Only positive values are # allowed. class ActionErrorTable include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simplified load configuration for actions # @!attribute [rw] replace # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Replace destination table # # Note: The following fields are mutually exclusive: `replace`, `append`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] append # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionSimpleLoadMode] # Append into destination table # # Note: The following fields are mutually exclusive: `append`, `replace`, `maximum`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] maximum # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value exceeds the previous maximum value for # a column in the destination table # # Note: The following fields are mutually exclusive: `maximum`, `replace`, `append`, `unique`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] unique # @return [::Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::DataPreparationAction::ActionIncrementalLoadMode] # Insert records where the value of a column is not already present in # the destination table # # Note: The following fields are mutually exclusive: `unique`, `replace`, `append`, `maximum`. If a field in that set is populated, all other fields in the set will automatically be cleared. class ActionLoadConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Simple load definition class ActionSimpleLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Load definition for incremental load modes # @!attribute [rw] column # @return [::String] # Column name for incremental load modes class ActionIncrementalLoadMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |