Class: Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::NotebookAction
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::WorkflowInvocationAction::NotebookAction
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a workflow action that will run against a Notebook runtime.
Instance Attribute Summary collapse
-
#contents ⇒ ::String
readonly
Output only.
-
#job_id ⇒ ::String
readonly
Output only.
Instance Attribute Details
#contents ⇒ ::String (readonly)
Returns Output only. The code contents of a Notebook to be run.
2476 2477 2478 2479 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2476 class NotebookAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#job_id ⇒ ::String (readonly)
Returns Output only. The ID of the Vertex job that executed the notebook in contents and also the ID used for the outputs created in Google Cloud Storage buckets. Only set once the job has started to run.
2476 2477 2478 2479 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 2476 class NotebookAction include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |