Class: Google::Cloud::Dataform::V1beta1::WorkflowTriggerConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Dataform::V1beta1::WorkflowTriggerConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/dataform/v1beta1/dataform.rb
Overview
Represents a trigger configuration for a workflow.
Defined Under Namespace
Modules: Condition
Instance Attribute Summary collapse
-
#condition ⇒ ::Google::Cloud::Dataform::V1beta1::WorkflowTriggerConfig::Condition
Optional.
-
#last_successful_evaluation_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#max_wait_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#min_execution_duration ⇒ ::Google::Protobuf::Duration
Optional.
-
#recent_trigger_evaluation_records ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::TriggerEvaluationRecord>
readonly
Output only.
-
#workflow_triggers ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::WorkflowTrigger>
Required.
Instance Attribute Details
#condition ⇒ ::Google::Cloud::Dataform::V1beta1::WorkflowTriggerConfig::Condition
Returns Optional. The condition to use when triggering the workflow.
1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1521 class WorkflowTriggerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The condition to use when triggering the workflow. module Condition # If CONDITION_UNSPECIFIED, the default value is ANY. CONDITION_UNSPECIFIED = 0 # If ALL, all the trigger config conditions must be met before a workflow # is invoked. ALL = 1 # If ANY, at least one of the trigger config conditions must be met # before a workflow is invoked. ANY = 2 end end |
#last_successful_evaluation_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The timestamp of the last successful trigger evaluation.
1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1521 class WorkflowTriggerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The condition to use when triggering the workflow. module Condition # If CONDITION_UNSPECIFIED, the default value is ANY. CONDITION_UNSPECIFIED = 0 # If ALL, all the trigger config conditions must be met before a workflow # is invoked. ALL = 1 # If ANY, at least one of the trigger config conditions must be met # before a workflow is invoked. ANY = 2 end end |
#max_wait_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. The effective maximum wait time duration for the trigger condition to be met. If not specified, the workflow won't be triggered until conditions are met.
1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1521 class WorkflowTriggerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The condition to use when triggering the workflow. module Condition # If CONDITION_UNSPECIFIED, the default value is ANY. CONDITION_UNSPECIFIED = 0 # If ALL, all the trigger config conditions must be met before a workflow # is invoked. ALL = 1 # If ANY, at least one of the trigger config conditions must be met # before a workflow is invoked. ANY = 2 end end |
#min_execution_duration ⇒ ::Google::Protobuf::Duration
Returns Optional. Minimum duration between two consecutive executions. If not specified, the workflow will be executed every time trigger conditions are met and there is no ongoing workflow execution.
1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1521 class WorkflowTriggerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The condition to use when triggering the workflow. module Condition # If CONDITION_UNSPECIFIED, the default value is ANY. CONDITION_UNSPECIFIED = 0 # If ALL, all the trigger config conditions must be met before a workflow # is invoked. ALL = 1 # If ANY, at least one of the trigger config conditions must be met # before a workflow is invoked. ANY = 2 end end |
#recent_trigger_evaluation_records ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::TriggerEvaluationRecord> (readonly)
Returns Output only. Records of the 10 most recent trigger evaluations, ordered
in descending order of evaluation_time. Updated whenever the service
evaluates the trigger conditions (via polling or upon receiving a push
event).
1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1521 class WorkflowTriggerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The condition to use when triggering the workflow. module Condition # If CONDITION_UNSPECIFIED, the default value is ANY. CONDITION_UNSPECIFIED = 0 # If ALL, all the trigger config conditions must be met before a workflow # is invoked. ALL = 1 # If ANY, at least one of the trigger config conditions must be met # before a workflow is invoked. ANY = 2 end end |
#workflow_triggers ⇒ ::Array<::Google::Cloud::Dataform::V1beta1::WorkflowTrigger>
Returns Required. The trigger definitions to invoke a workflow.
1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 |
# File 'proto_docs/google/cloud/dataform/v1beta1/dataform.rb', line 1521 class WorkflowTriggerConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The condition to use when triggering the workflow. module Condition # If CONDITION_UNSPECIFIED, the default value is ANY. CONDITION_UNSPECIFIED = 0 # If ALL, all the trigger config conditions must be met before a workflow # is invoked. ALL = 1 # If ANY, at least one of the trigger config conditions must be met # before a workflow is invoked. ANY = 2 end end |